@@ -14,18 +14,21 @@
 #include <config.h>
 
 #include "amarokconfig.h"
+#include "moodbar.h"
 #include <kstandarddirs.h>
 
 
 void Options1::init()
 {
+    slotUpdateMoodFrame();
+    
     QStringList browsers;
     browsers << "konqueror" << "firefox" << "opera" << "galeon" << "epiphany"
              << "safari" << "mozilla";
 
     // Remove browsers which are not actually installed
     for( QStringList::Iterator it = browsers.begin(), end = browsers.end(); it != end; ) {
-        if( KStandardDirs::findExe( *it ) == QString::null )
+        if( KStandardDirs::findExe( *it ).isEmpty() )
             it = browsers.erase( it );
         else
             ++it;
@@ -38,3 +41,25 @@ void Options1::init()
                                        0 :
                                        browsers.findIndex( AmarokConfig::externalBrowser() ) );
 }
+
+
+
+void Options1::slotUpdateMoodFrame()
+{
+    if( Moodbar::executableExists() )
+      {
+        moodbarHelpLabel->hide();
+        moodFrame->setEnabled(true);
+
+        kcfg_MakeMoodier->setEnabled(kcfg_ShowMoodbar->isChecked());
+        kcfg_AlterMood->setEnabled(kcfg_ShowMoodbar->isChecked() && kcfg_MakeMoodier->isChecked());
+        kcfg_MoodsWithMusic->setEnabled(kcfg_ShowMoodbar->isChecked());
+      }
+
+    else
+      {
+        moodbarHelpLabel->show();
+        kcfg_ShowMoodbar->setChecked(false);
+        moodFrame->setEnabled(false);
+      }
+}
