@@ -56,7 +56,7 @@ void Options5::init()
     connect( kcfg_OsdEnabled,         SIGNAL( toggled(bool) ),
              m_pOSDPreview,           SLOT( setShown(bool) ) );
 
-    amaroK::QStringx text = i18n(
+    Amarok::QStringx text = i18n(
             "<h3>Tags Displayed in OSD</h3>"
             "You can use the following tokens:"
                 "<ul>"
@@ -75,6 +75,8 @@ void Options5::init()
                 "<li>Score - %13"
                 "<li>Playcount - %14"
                 "<li>Disc Number - %15"
+                "<li>Rating - %16"
+                "<li>Moodbar - %17"
                 "</ul>"
             "If you surround sections of text that contain a token with curly-braces, that section will be hidden if the token is empty, for example:"
                 "<pre>%11</pre>"
@@ -85,6 +87,7 @@ void Options5::init()
             << "%title" << "%album"   << "%artist" << "%genre"     << "%bitrate"
             << "%year " << "%length"  << "%track"  << "%file"      << "%directory"
             << "%type"  << "%comment" << "%score"  << "%playcount" << "%discnumber"
+            << "%rating" << "%moodbar"
             << "%title {Score: %score}" ) );
 }
 
