@@ -7,6 +7,9 @@
 #include <qstring.h>
 
 #include <kurl.h> // recursiveUrlExpand
+#include <kprocio.h> //Amarok::ProcIO
+#include <kio/netaccess.h>
+#include <kdeversion.h>
 
 #include "amarok_export.h"
 
@@ -15,12 +18,15 @@ class KConfig;
 class QColor;
 class QDateTime;
 class QEvent;
+class QMutex;
 class QPixmap;
 class QWidget;
 class DynamicMode;
+class QListView;
+class QListViewItem;
 namespace KIO { class Job; }
 
-namespace amaroK
+namespace Amarok
 {
     const int VOLUME_MAX = 100;
     const int SCOPE_SIZE = 9; //= 2**9 = 512
@@ -28,13 +34,15 @@ namespace amaroK
     const int VOLUME_SENSITIVITY = 30; //for mouse wheels
     const int GUI_THREAD_ID = 0;
 
+    extern QMutex globalDirsMutex; // defined in app.cpp
+
     namespace ColorScheme
     {
         ///eg. base of the Amarok Player-window
-        extern QColor Base; //amaroK::blue
+        extern QColor Base; //Amarok::blue
         ///eg. text in the Amarok Player-window
         extern QColor Text; //Qt::white
-        ///eg. background colour for amaroK::PrettySliders
+        ///eg. background colour for Amarok::PrettySliders
         extern QColor Background; //brighter blue
         ///eg. outline of slider widgets in Player-window
         extern QColor Foreground; //lighter blue
@@ -68,7 +76,7 @@ namespace amaroK
      * playlist. You shouldn't pass every event here, ie closeEvents will not be
      * handled as expected! Check the source in app.cpp if you want to see what
      * it can do.
-     * @param recipient The object that recieved the event.
+     * @param recipient The object that received the event.
      * @param e The event you want handled in a generic fashion.
      * @return true if the event was handled.
      */
@@ -141,6 +149,16 @@ namespace amaroK
         return fileName.contains( '.' ) ? fileName.mid( fileName.findRev( '.' ) + 1 ).lower() : "";
     }
 
+    /** Transform url into a file url if possible */
+    inline KURL mostLocalURL( const KURL &url )
+    {
+#if KDE_VERSION < KDE_MAKE_VERSION(3,5,0)
+        return url;
+#else
+        return KIO::NetAccess::mostLocalURL( url, mainWindow() );
+#endif
+    }
+
     /**
      * @return the last directory in @param fileName
      */
@@ -149,7 +167,7 @@ namespace amaroK
         return fileName.section( '/', 0, -2 );
     }
   /** Due to xine-lib, we have to make KProcess close all fds, otherwise we get "device is busy" messages
-  * Used by AmaroKProcIO and AmaroKProcess, exploiting commSetupDoneC(), a virtual method that
+  * Used by Amarok::ProcIO and Amarok::Process, exploiting commSetupDoneC(), a virtual method that
   * happens to be called in the forked process
   * See bug #103750 for more information.
   */
@@ -164,6 +182,7 @@ namespace amaroK
 
     void setUseScores( bool use ); //defined in app.cpp
     void setUseRatings( bool use );
+    void setMoodbarPrefs( bool show, bool moodier, int alter, bool withMusic );
 
     bool repeatNone(); //defined in actionclasses.cpp
     bool repeatTrack();
@@ -180,6 +199,8 @@ namespace amaroK
 
     const DynamicMode *dynamicMode(); //defined in playlist.cpp
 
+    QListViewItem* findItemByPath( QListView *view, QString path ); //defined in playlistbrowser.cpp
+
     /**
      * Maps the icon name to a system icon or custom Amarok icon, depending on the settings.
      */
@@ -188,10 +209,16 @@ namespace amaroK
     /**
      * Removes accents from the string
      * @param path The original path.
-     * @param onlyASCII If set, non-ascii chars will be replaced by '_'.
      * @return The cleaned up path.
      */
-    LIBAMAROK_EXPORT QString cleanPath( const QString &path, bool onlyASCII = false ); //defined in app.cpp
+    LIBAMAROK_EXPORT QString cleanPath( const QString &path ); //defined in app.cpp
+
+    /**
+     * Replaces all non-ASCII characters with '_'.
+     * @param path The original path.
+     * @return The ASCIIfied path.
+     */
+    LIBAMAROK_EXPORT QString asciiPath( const QString &path ); //defined in app.cpp
 
     /**
      * Transform path into one valid on VFAT file systems
@@ -215,6 +242,60 @@ namespace amaroK
     LIBAMAROK_EXPORT QString escapeHTML( const QString &s );
     LIBAMAROK_EXPORT QString escapeHTMLAttr( const QString &s );
     LIBAMAROK_EXPORT QString unescapeHTMLAttr( const QString &s );
+
+    /* defined in scriptmanager.cpp */
+    /**
+     * Returns the proxy that should be used for a given URL.
+     * @param url the url.
+     * @return The url of the proxy, or a empty string if no proxy should be used.
+     */
+    QString proxyForUrl(const QString& url);
+
+    /**
+     * Returns the proxy that should be used for a given protocol.
+     * @param protocol the protocol.
+     * @return The url of the proxy, or a empty string if no proxy should be used.
+     */
+    QString proxyForProtocol(const QString& protocol);
+
+    ////////////////////////////////////////////////////////////////////////////////
+    // class Amarok::ProcIO
+    ////////////////////////////////////////////////////////////////////////////////
+    /**
+    * Due to xine-lib, we have to make KProcess close all fds, otherwise we get "device is busy" messages
+    * Used by Amarok::ProcIO and AmarokProcess, exploiting commSetupDoneC(), a virtual method that
+    * happens to be called in the forked process
+    * See bug #103750 for more information.
+    */
+    class LIBAMAROK_EXPORT ProcIO : public KProcIO {
+        public:
+        ProcIO(); // ctor sets the textcodec to UTF-8, in scriptmanager.cpp
+        virtual int commSetupDoneC() {
+            const int i = KProcIO::commSetupDoneC();
+            Amarok::closeOpenFiles( KProcIO::out[0],KProcIO::in[0],KProcIO::err[0] );
+            return i;
+        };
+    };
+
+    ////////////////////////////////////////////////////////////////////////////////
+    // class Amarok::Process
+    ////////////////////////////////////////////////////////////////////////////////
+    /** Due to xine-lib, we have to make KProcess close all fds, otherwise we get "device is busy" messages
+     * Used by Amarok::ProcIO and Amarok::Process, exploiting commSetupDoneC(), a virtual method that
+     * happens to be called in the forked process
+     * See bug #103750 for more information.
+     */
+    class LIBAMAROK_EXPORT Process : public KProcess {
+        public:
+        Process( QObject *parent = 0 ) : KProcess( parent ) {}
+        virtual int commSetupDoneC() {
+            const int i = KProcess::commSetupDoneC();
+            Amarok::closeOpenFiles(KProcess::out[0],KProcess::in[0], KProcess::err[0]);
+            return i;
+        };
+    };
+
+
 }
 
 
@@ -253,6 +334,6 @@ namespace amaroK
 
 
 /// Update this when necessary
-#define APP_VERSION "1.4.1"
+#define APP_VERSION "1.4.4"
 
 #endif
