@@ -1,4 +1,4 @@
-// Maintainer: Max Howell <mac.howell@methylblue.com>, (C) 2003-4
+// Maintainer: Max Howell <mac.howell@methylblue.com>, (C) 2003-5
 // Copyright:  See COPYING file that comes with this distribution
 //
 
@@ -6,15 +6,17 @@
 #define BLOCKANALYZER_H
 
 #include "analyzerbase.h"
-
-/**
-@author Max Howell
-*/
+#include <qcolor.h>
 
 class QResizeEvent;
 class QMouseEvent;
 class QPalette;
 
+
+/**
+ * @author Max Howell
+ */
+
 class BlockAnalyzer : public Analyzer::Base2D
 {
 public:
@@ -26,6 +28,7 @@ public:
     static const uint MIN_ROWS    = 3;   //arbituary
     static const uint MIN_COLUMNS = 32;  //arbituary
     static const uint MAX_COLUMNS = 256; //must be 2**n
+    static const uint FADE_SIZE   = 90;
 
 protected:
     virtual void transform( Scope& );
@@ -38,15 +41,21 @@ protected:
     void determineStep();
 
 private:
-    QPixmap* const glow() { return &m_glow; }
+    QPixmap* const bar() { return &m_barPixmap; }
 
     uint m_columns, m_rows;      //number of rows and columns of blocks
     uint m_y;                    //y-offset from top of widget
-    QPixmap m_glow;
+    QPixmap m_barPixmap;
+    QPixmap m_topBarPixmap;
     Scope m_scope;               //so we don't create a vector every frame
     std::vector<float> m_store;  //current bar heights
     std::vector<float> m_yscale;
 
+    //FIXME why can't I namespace these? c++ issue?
+    std::vector<QPixmap> m_fade_bars;
+    std::vector<uint>    m_fade_pos;
+    std::vector<int>     m_fade_intensity;
+
     float m_step; //rows to fall per frame
 };
 
