@@ -14,11 +14,15 @@
 #include "amarok_export.h"  //LIBAMAROK_EXPORT
 #include <qwidget.h>        //baseclass
 #include <qvaluevector.h>   //stack allocated
+#include <qmap.h>           //stack allocated
+#include <qpushbutton.h>
 
 typedef QValueVector<QWidget*> BrowserList;
+typedef QMap<QString,int> BrowserIdMap;
 
 class MultiTabBar;
 class MultiTabBarTab;
+class DropProxyTarget;
 class KURL;
 class QSignalMapper;
 class QVBox;
@@ -34,6 +38,7 @@ public:
 
     LIBAMAROK_EXPORT static BrowserBar* instance() { return s_instance; }
     QVBox *container() const { return m_playlistBox; }
+    QVBox *browserBox() const { return m_browserBox; }
 
     QWidget *browser( const QString& ) const;
     QWidget *browser( int index ) const { if( index < 0 ) index = 0; return m_browsers[index]; }
@@ -42,13 +47,14 @@ public:
     int count() const { return m_browsers.count(); }
     int visibleCount() const;
 
-    void addBrowser( QWidget*, const QString&, const QString& );
+    void addBrowser( const QString &identifier, QWidget*, const QString&, const QString& );
     void removeMediaBrowser( QWidget *widget );
     int indexForName( const QString& ) const;
     int restoreWidth();
 
     /// for internal use
     void mouseMovedOverSplitter( QMouseEvent* );
+    void makeDropProxy( const QString &browserName, DropProxyTarget *finalTarget );
 
 protected:
     virtual bool event( QEvent* );
@@ -60,13 +66,14 @@ public slots:
     void showHideBrowser( int );
     void showHideVisibleBrowser( int );
     void closeCurrentBrowser() { showHideBrowser( m_currentIndex ); }
+    void showBrowserSelectionMenu();
 
 signals:
     void browserActivated( int );
 
 private:
     void adjustWidgetSizes();
-    uint maxBrowserWidth() const { return width() / 2; }
+    uint maxBrowserWidth() const { return width() * 2 / 3; }
 
     static const int DEFAULT_HEIGHT = 50;
 
@@ -76,11 +83,16 @@ private:
     QWidget       *m_divider;     ///a qsplitter like widget
     MultiTabBar   *m_tabBar;
     BrowserList    m_browsers;
-    QWidget       *m_browserBox;  ///parent widget to the browsers
+    BrowserIdMap   m_browserIds;
+    QVBox         *m_browserBox;  ///parent widget to the browsers
     int            m_currentIndex;
     int            m_lastIndex;
     QSignalMapper *m_mapper;      ///maps tab clicks to browsers
-    int            m_mediaBrowserId; ///id of media browser, so can be both inserted and removed
+
+    QPushButton   *m_tabManagementButton;
+
+
+    
 };
 
 #endif
