@@ -7,8 +7,9 @@
 #ifndef AMAROK_COLLECTIONBROWSER_H
 #define AMAROK_COLLECTIONBROWSER_H
 
-#include "qlabel.h"
-#include "qvbox.h"           //baseclass
+#include <qlabel.h>
+#include <qvaluelist.h>      //stack allocated
+#include <qvbox.h>           //baseclass
 
 #include <klistview.h>       //baseclass
 #include <qstringlist.h>     //stack allocated
@@ -16,6 +17,7 @@
 #include <kdialogbase.h>     //baseclass
 #include <kprogress.h>
 
+#include "multitabbar.h"     //baseclass
 #include "collectiondb.h"
 #include "amarok_export.h"
 
@@ -33,6 +35,7 @@ class KComboBox;
 class KPopupMenu;
 class KRadioAction;
 class KTabBar;
+class KToolBar;
 class KToggleAction;
 
 class CollectionView;
@@ -40,6 +43,17 @@ class CollectionItem;
 class DividerItem;
 class OrganizeCollectionDialog;
 
+namespace CollectionBrowserIds
+{
+    enum CatMenuId { IdAlbum = QueryBuilder::tabAlbum,
+    IdArtist = QueryBuilder::tabArtist,
+    IdComposer = QueryBuilder::tabComposer,
+    IdGenre = QueryBuilder::tabGenre,
+    IdYear = QueryBuilder::tabYear ,
+    IdScan = 32, IdNone = 64,
+    IdArtistAlbum = 128, IdGenreArtist = 256, IdGenreArtistAlbum = 512, IdVisYearAlbum = 1024, IdArtistVisYearAlbum = 2048 };
+}
+
 class CollectionBrowser: public QVBox
 {
     Q_OBJECT
@@ -48,6 +62,8 @@ class CollectionBrowser: public QVBox
     public:
         CollectionBrowser( const char* name );
         virtual bool eventFilter( QObject*, QEvent* );
+        KToolBar* getToolBar() const { return m_toolbar; }
+        static CollectionBrowser *instance() { return s_instance; }
 
     public slots:
         void setupDirs();
@@ -59,19 +75,23 @@ class CollectionBrowser: public QVBox
 
     private:
         void layoutToolbar();
+        void ipodToolbar( bool activate );
         void appendSearchResults();
 
         //attributes:
-        enum CatMenuId { IdAlbum = 1, IdArtist = 2, IdGenre = 4, IdYear = 8 , IdScan = 16, IdNone = 32,
-                    IdArtistAlbum = 64, IdGenreArtist = 128, IdGenreArtistAlbum = 256, IdVisYearAlbum = 512, IdArtistVisYearAlbum = 1024 };
-
         KTabBar* m_tabs; //tree-view, flat-view tabs
         class KToolBar    *m_toolbar;
         KAction           *m_configureAction;
         KAction           *m_scanAction;
+        // For iPod-style browsing
+        KAction           *m_ipodIncrement, *m_ipodDecrement;
+        class KToolBar    *m_ipodToolbar;
+        class QHBox       *m_ipodHbox;
+
         KToggleAction     *m_showDividerAction;
         KRadioAction      *m_treeViewAction;
         KRadioAction      *m_flatViewAction;
+        KRadioAction      *m_ipodViewAction;
         class KActionMenu *m_tagfilterMenuButton;
 
         KPopupMenu* m_categoryMenu;
@@ -85,6 +105,8 @@ class CollectionBrowser: public QVBox
 
         bool m_returnPressed;
 
+        static CollectionBrowser *s_instance;
+
     // for CatMenuId
     friend class CollectionItem;
     friend class DividerItem;
@@ -154,13 +176,13 @@ class CollectionItem : public KListViewItem {
 };
 
 
-class CollectionView : public KListView
+class CollectionView : public KListView, public DropProxyTarget
 {
     Q_OBJECT
     friend class CollectionBrowser;
 
     public:
-        enum ViewMode  { modeTreeView, modeFlatView };
+        enum ViewMode  { modeTreeView, modeFlatView, modeIpodView };
 
         friend class CollectionItem; // for access to m_cat2
         friend class ContextBrowser; // for setupDirs()
@@ -177,12 +199,20 @@ class CollectionView : public KListView
         CollectionItem* currentItem() { return static_cast<CollectionItem*>( KListView::currentItem() ); }
 
         int trackDepth() { return m_trackDepth; }
+        int viewMode() const { return m_viewMode; }
 
         // Transform "The Who" -> "Who, The" or the other way
         static void manipulateThe( QString &str, bool reverse );
 
         void setShowDivider(bool show);
 
+        bool isOrganizingFiles() const;
+
+    protected:
+        // Reimplemented for iPod-style navigation, etc.
+        virtual void keyPressEvent( QKeyEvent *e );
+
+
     public slots:
         /** Rebuilds and displays the treeview by querying the database. */
         void renderView(bool force = false);
@@ -191,6 +221,7 @@ class CollectionView : public KListView
 
         void setTreeMode() { setViewMode( modeTreeView ); };
         void setFlatMode() { setViewMode( modeFlatView ); };
+        void setIpodMode() { setViewMode( modeIpodView ); };
 
         void presetMenu( int id );
         void cat1Menu( int id, bool rerender = true );
@@ -201,13 +232,24 @@ class CollectionView : public KListView
     private slots:
         void setupDirs();
 
+        void renderFlatModeView(bool force = false);
+        void renderTreeModeView(bool force = false);
+        void renderIpodModeView(bool force = false);
+
         void scanStarted();
         void scanDone( bool changed = true );
 
         void slotExpand( QListViewItem* );
         void slotCollapse( QListViewItem* );
         void enableCat3Menu( bool );
+        void invokeItem( QListViewItem*, const QPoint &, int column );
         void invokeItem( QListViewItem* );
+
+        // ipod-style navigation slots
+        void ipodItemClicked( QListViewItem*, const QPoint&, int );
+        void incrementDepth ( bool rerender = true );
+        void decrementDepth ( bool rerender = true );
+
         void rmbPressed( QListViewItem*, const QPoint&, int );
         void selectAll() {QListView::selectAll(true); }
         /** Tries to download the cover image from Amazon.com */
@@ -216,11 +258,13 @@ class CollectionView : public KListView
         void showTrackInfo();
 
     private:
-        enum Tag { Title, Artist, Composer, Album, Genre, Length, DiscNumber, Track, Year,
+        enum Tag { Title = 0, Artist, Composer, Album, Genre, Length, DiscNumber, Track, Year,
             Comment, Playcount, Score, Rating, Filename, Firstplay, Lastplay, Modified,
-            Bitrate, Filesize };
+            Bitrate, Filesize, BPM, NUM_TAGS };
 
         void setViewMode( int mode, bool rerender = true );
+        void removeDuplicatedHeaders();
+
         void startDrag();
         KURL::List listSelected();
 
@@ -229,6 +273,14 @@ class CollectionView : public KListView
         QString captionForCategory( const int cat ) const;
         inline QString captionForTag( const Tag ) const;
 
+        // For iPod-style navigation
+        QString allForCategory( const int cat, const int num ) const;
+        void resetIpodDepth ( void );
+        void buildIpodQuery ( QueryBuilder &qb, int depth, QStringList filters[3], QStringList filterYear, bool recursiveSort = false, bool compilationsOnly = false );
+        void selectIpodItems ( void );
+        QPixmap ipodIncrementIcon ( void );
+        QPixmap ipodDecrementIcon ( void );
+
         void setCompilation( const QString &album, bool compilation );
 
         /** Rebuild selections, viewport and expanded items after reloads */
@@ -251,6 +303,8 @@ class CollectionView : public KListView
         void contentsDragEnterEvent( QDragEnterEvent* );
         void contentsDragMoveEvent( QDragMoveEvent* );
         void contentsDropEvent( QDropEvent *e );
+        // Reimplemented from DropProxyTarget
+        void dropProxyEvent( QDropEvent *e );
 
         void safeClear();
 
@@ -266,6 +320,17 @@ class CollectionView : public KListView
         int m_cat3;
         int m_trackDepth;
         int m_viewMode;
+
+        // The iPod-style viewing attributes
+        int         m_currentDepth;   // Current viewing depth
+        QStringList m_ipodFilters[3]; // Selections at each stage
+        QStringList m_ipodFilterYear; // See the comment for incrementDepth()
+        // For auto-selection
+        int         m_ipodIncremented; // 0 = nothing, 1 = just incremented, 2 = just decremented
+        QStringList m_ipodSelected[3]; // Saved selections at lower levels
+        QString     m_ipodCurrent[3];  // Saved current selections
+        QString     m_ipodTopItem[3];  // Saved viewport positions
+
         bool m_dirty; // we use this to avoid re-rendering the view when unnecessary (eg, browser is not visible)
 
         QValueList<QStringList> m_cacheOpenItemPaths;
@@ -275,6 +340,7 @@ class CollectionView : public KListView
         bool                    m_organizeCopyMode;
 
         bool m_showDivider;
+        QValueList<int>         m_flatColumnWidths;
 };
 
 // why is signal detailsClicked() missing from KDialogBase?
