@@ -28,6 +28,7 @@
 #include <qstringlist.h>     //stack allocated
 #include <qptrvector.h>
 #include <qthread.h>
+#include <qvaluestack.h>
 
 namespace KIO { class Job; }
 
@@ -206,6 +207,11 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
         void ratingChanged( const QString &url, int rating );
         void fileMoved( const QString &srcUrl, const QString &dstUrl );
         void fileMoved( const QString &srcUrl, const QString &dstUrl, const QString &uniqueid );
+        void fileDeleted( const QString &absPath );
+        void fileDeleted( const QString &absPath, const QString &uniqueid );
+        void fileAdded( const QString &absPath );
+        void fileAdded( const QString &absPath, const QString &uniqueid );
+        void filesAdded( const QMap<QString,QString> &map );
         void uniqueIdChanged( const QString &url, const QString &originalid, const QString &newid );
         void coverChanged( const QString &artist, const QString &album ); //whenever a cover changes
         void coverFetched( const QString &artist, const QString &album ); //only when fetching from amazon
@@ -262,10 +268,10 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
         //sql helper methods
         QStringList query( const QString& statement );
         int insert( const QString& statement, const QString& table );
-        
+
         /**
          * TODO: write doc
-         * @param showAll 
+         * @param showAll
          * @return a string which can be appended to an existing sql where statement
          */
         QString deviceidSelection( const bool showAll = false );
@@ -306,13 +312,18 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
         bool isFileInCollection( const QString &url );
         QString getURL( const MetaBundle &bundle );
         void removeDirFromCollection( QString path );
-        void removeSongsInDir( QString path );
+        void removeSongsInDir( QString path, QMap<QString,QString> *tagsRemoved = 0 );
         void removeSongs( const KURL::List& urls );
         void updateDirStats( QString path, const long datetime, const bool temporary = false );
 
         //song methods
         bool addSong( MetaBundle* bundle, const bool incremental = false );
         void doAFTStuff( MetaBundle *bundle, const bool tempTables = true );
+        void emitFileAdded( const QString &absPath,
+                            const QString &uniqueid = QString::null );
+        void emitFilesAdded( const QMap<QString,QString> &map ) { emit filesAdded( map ); }
+        void emitFileDeleted( const QString &absPath,
+                              const QString &uniqueid = QString::null );
         bool newUniqueIdForFile( const QString &path );
         bool removeUniqueIdFromFile( const QString &path );
         QString urlFromUniqueId( const QString &id );
@@ -350,7 +361,9 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
         void addAudioproperties( const MetaBundle& bundle );
 
         //Helper function for updateTags
-        void deleteRedundantName( const QString &table, QString ID );
+        void deleteRedundantName( const QString &table, const QString &id );
+
+        void deleteAllRedundant( const QString &table );
 
         void updateTags( const QString &url, const MetaBundle &bundle, const bool updateView = true);
         void updateURL( const QString &url, const bool updateView = true );
@@ -461,6 +474,8 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
 
         void invalidateArtistAlbumCache() { m_validArtistCache=false; m_validComposerCache=false; m_validAlbumCache=false; };
 
+        void vacuum();
+
     protected:
         QCString md5sum( const QString& artist, const QString& album, const QString& file = QString::null );
         void engineTrackEnded( int finalPosition, int trackLength, const QString &reason );
@@ -560,7 +575,7 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
         //Use the Exact version where possible (faster and safer).
         //To convert output from Exact version from QString to uint, use .toUInt()
         uint IDFromValue( QString name, QString value, bool autocreate = true, const bool temporary = false );
-        QString IDfromExactValue(  QString table, QString value, bool autocreate = true, bool temporary = false );
+        QString IDFromExactValue(  QString table, QString value, bool autocreate = true, bool temporary = false );
         QString valueFromID( QString table, uint id );
 
         //member variables
@@ -608,7 +623,7 @@ class INotify : public ThreadWeaver::DependentJob
 
         static INotify *instance() { return s_instance; }
 
-        bool watchDir( QString directory );
+        bool watchDir( const QString directory );
         int fd() { return m_fd; }
 
     private:
@@ -678,9 +693,13 @@ class QueryBuilder
         static const Q_INT64 valDeviceLabel   = 1LL << 38;
         static const Q_INT64 valMountPoint    = 1LL << 39;
 
+        static Q_INT64 valForFavoriteSorting();
+
         enum qBuilderFunctions  { funcNone = 0, funcCount = 1, funcMax = 2, funcMin = 4, funcAvg = 8, funcSum = 16 };
 
-        enum qBuilderFilter  { modeNormal = 0, modeLess = 1, modeGreater = 2, modeEndMatch = 3 };
+        // Note: modes beginMatch, endMatch are only supported for string filters
+        // Likewise, modes between and notBetween are only supported for numeric filters
+        enum qBuilderFilter  { modeNormal = 0, modeLess = 1, modeGreater = 2, modeEndMatch = 3, modeBeginMatch = 4, modeBetween = 5, modeNotBetween = 6};
 
         QueryBuilder();
 
@@ -688,10 +707,11 @@ class QueryBuilder
         void addReturnFunctionValue( int function, int table, Q_INT64 value);
         uint countReturnValues();
 
+        // Note: the filter chain begins in AND mode
         void beginOR(); //filters will be ORed instead of ANDed
         void endOR();   //don't forget to end it!
         void beginAND(); // These do the opposite; for recursive and/or
-        void endAND();   
+        void endAND();
 
         void setGoogleFilter( int defaultTables, QString query );
 
@@ -711,12 +731,26 @@ class QueryBuilder
 
         void exclusiveFilter( int tableMatching, int tableNotMatching, Q_INT64 value );
 
+        // For numeric filters:
+        // modeNormal means strict equality; modeBeginMatch and modeEndMatch are not
+        // allowed; modeBetween needs a second value endRange
+        void addNumericFilter(int tables, Q_INT64 value, const QString &n,
+                              int mode = modeNormal,
+                              const QString &endRange = QString::null);
+
         void setOptions( int options );
         void sortBy( int table, Q_INT64 value, bool descending = false );
         void sortByFunction( int function, int table, Q_INT64 value, bool descending = false );
         void groupBy( int table, Q_INT64 value );
         void setLimit( int startPos, int length );
 
+        // Returns the results in random order.
+        // If a \p table and \p value are specified, uses weighted random order on
+        // that field.
+        // The shuffle is cumulative with other sorts, but any sorts after this are
+        // pointless because of the precision of the random function.
+        void shuffle( int table = 0, Q_INT64 value = 0 );
+
         static const int dragFieldCount;
         static QString dragSQLFields();
         void initSQLDrag();
@@ -728,16 +762,24 @@ class QueryBuilder
 
         QStringList run();
 
+        // Transform a string table.value "field" into enum values
+        // @return true if we succeded
+        bool getField(const QString &tableValue, int *table, Q_INT64 *value);
+
     private:
         QString tableName( int table );
-        QString valueName( Q_INT64 value );
+        const QString &valueName( Q_INT64 value );
         QString functionName( int functions );
-        
+        bool coalesceField( int table, Q_INT64 value );
+
+        int getTableByName(const QString &name);
+        Q_INT64 getValueByName(const QString &field);
+
         QStringList cleanURL( QStringList result );
 
         void linkTables( int tables );
 
-        bool m_OR;
+        QValueStack<bool> m_OR;
         bool m_showAll;
         uint m_deviceidPos;
 
@@ -761,25 +803,25 @@ class QueryBuilder
 
 inline void QueryBuilder::beginOR()
 {
-    m_OR = true;
-    m_where += "AND ( " + CollectionDB::instance()->boolF() + " ";
+    m_where += ANDslashOR() + " ( " + CollectionDB::instance()->boolF() + ' ';
+    m_OR.push(true);
 }
 inline void QueryBuilder::endOR()
 {
-    m_OR = false;
     m_where += " ) ";
+    m_OR.pop();
 }
 inline void QueryBuilder::beginAND()
 {
-    m_OR = false;
-    m_where += "OR ( " + CollectionDB::instance()->boolT() + " ";
+    m_where += ANDslashOR() + " ( " + CollectionDB::instance()->boolT() + ' ';
+    m_OR.push(false);
 }
 inline void QueryBuilder::endAND()
 {
-    m_OR = true;
     m_where += " ) ";
+    m_OR.pop();
 }
-inline QString QueryBuilder::ANDslashOR() const { return m_OR ? "OR" : "AND"; }
+inline QString QueryBuilder::ANDslashOR() const { return m_OR.top() ? "OR" : "AND"; }
 
 
 #endif /* AMAROK_COLLECTIONDB_H */
