@@ -92,8 +92,8 @@ int HSPPreMixAudioHook::volumeize(unsigned char *data, unsigned char *outbuf, si
 }
 
 void HSPPreMixAudioHook::setFadeout(bool fadeout)
-{ 
-   m_fadeout = fadeout; 
+{
+   m_fadeout = fadeout;
    if (m_fadeout)
    {
       // the "time constant" (ms) is the time it takes to reach +6db of the target
@@ -144,7 +144,7 @@ STDMETHODIMP HSPPreMixAudioHook::OnBuffer(HXAudioData *pAudioInData, HXAudioData
       {
          ibuf->SetSize(len);
          outbuf = ibuf->GetBuffer();
-         
+
          len = volumeize(data, outbuf, len);
 
          pAudioOutData->pData = ibuf;
@@ -158,7 +158,7 @@ STDMETHODIMP HSPPreMixAudioHook::OnBuffer(HXAudioData *pAudioInData, HXAudioData
 
 STDMETHODIMP HSPPreMixAudioHook::OnInit(HXAudioFormat *pFormat)
 {
-   m_Player->print2stderr("PRE MIX HOOK OnInit AudioFormat: ch %d, bps %d, sps %d, mbs %d\n", pFormat->uChannels,
+   m_Player->print2stderr("PRE MIX HOOK OnInit AudioFormat: ch %d, bps %d, sps %ld, mbs %d\n", pFormat->uChannels,
           pFormat->uBitsPerSample,
           pFormat->ulSamplesPerSec,
           pFormat->uMaxBlockSize);
@@ -339,7 +339,7 @@ STDMETHODIMP HSPPostProcessor::OnInit(HXAudioFormat *pFormat)
    switch(pFormat->ulSamplesPerSec)
    {
       case 8000:
-         //iir_cf = iir_cf10_8000;  <-- doesnt work
+         //iir_cf = iir_cf10_8000;  <-- doesn't work
          iir_cf = iir_cf10_11k_11025; // works
          break;
 
@@ -349,7 +349,7 @@ STDMETHODIMP HSPPostProcessor::OnInit(HXAudioFormat *pFormat)
          break;
 
       case 16000:
-         //iir_cf = iir_cf10_16000; <-- doesnt work
+         //iir_cf = iir_cf10_16000; <-- doesn't work
          iir_cf = iir_cf10_22k_22050; // works
          break;
 
@@ -554,7 +554,7 @@ int HSPPostProcessor::volumeize(unsigned char *data, unsigned char *outbuf, size
 }
 #endif
 
-HSPPostMixAudioHook::HSPPostMixAudioHook(HelixSimplePlayer *player, int playerIndex) :  
+HSPPostMixAudioHook::HSPPostMixAudioHook(HelixSimplePlayer *player, int playerIndex) :
    m_Player(player), m_index(playerIndex), m_lRefCount(0), m_processor(0)
 {
    AddRef();
@@ -622,13 +622,13 @@ STDMETHODIMP HSPPostMixAudioHook::OnBuffer(HXAudioData *pAudioInData, HXAudioDat
    // feed the visualizations, if this is a local file (otherwise do it in the FinalHook)
    if (m_Player->isLocal(m_index))
       m_processor->scopeify(pAudioInData->ulAudioTime, data, len);
-   
+
    return 0;
 }
 
 STDMETHODIMP HSPPostMixAudioHook::OnInit(HXAudioFormat *pFormat)
 {
-   m_Player->print2stderr("POST MIX HOOK OnInit AudioFormat: idx %d ch %d, bps %d, sps %d, mbs %d\n", m_index, pFormat->uChannels,
+   m_Player->print2stderr("POST MIX HOOK OnInit AudioFormat: idx %d ch %d, bps %d, sps %ld, mbs %d\n", m_index, pFormat->uChannels,
           pFormat->uBitsPerSample,
           pFormat->ulSamplesPerSec,
           pFormat->uMaxBlockSize);
@@ -732,7 +732,7 @@ STDMETHODIMP HSPFinalAudioHook::OnBuffer(HXAudioData *pAudioInData, HXAudioData
 
 STDMETHODIMP HSPFinalAudioHook::OnInit(HXAudioFormat *pFormat)
 {
-   m_Player->print2stderr("FINAL HOOK OnInit AudioFormat: ch %d, bps %d, sps %d, mbs %d\n",  pFormat->uChannels,
+   m_Player->print2stderr("FINAL HOOK OnInit AudioFormat: ch %d, bps %d, sps %ld, mbs %d\n",  pFormat->uChannels,
           pFormat->uBitsPerSample,
           pFormat->ulSamplesPerSec,
           pFormat->uMaxBlockSize);
