@@ -54,7 +54,7 @@ class LIBAMAROK_EXPORT MediaItem : public KListViewItem
 
         MediaItem *lastChild() const;
 
-        KURL url() const;
+        virtual KURL url() const;
         const MetaBundle *bundle() const;
         void setBundle( MetaBundle *bundle );
 
@@ -81,6 +81,8 @@ class LIBAMAROK_EXPORT MediaItem : public KListViewItem
         virtual bool ratingChanged()  const { return false; }
         virtual long size()           const;
         virtual MediaDevice *device() const { return m_device; }
+        virtual bool listened()       const { return m_listened; }
+        virtual void setListened( bool listened=true ) { m_listened = listened; }
 
         int compare( QListViewItem *i, int col, bool ascending ) const;
         int flags() const { return m_flags; }
@@ -94,6 +96,7 @@ class LIBAMAROK_EXPORT MediaItem : public KListViewItem
         QString         m_data;
         MediaDevice    *m_device;
         int             m_flags;
+        bool            m_listened;
 
         static QPixmap *s_pixUnknown;
         static QPixmap *s_pixRootItem;
@@ -124,6 +127,10 @@ class MediaQueue : public KListView, public DropProxyTarget
         MediaItem *findPath( QString path );
 
         KIO::filesize_t totalSize() const; // total size of items to transfer in KB
+        void computeSize() const; // compute total size of items to transfer in KB
+        void addItemToSize( const MediaItem *item ) const;
+        void subtractItemFromSize( const MediaItem *item, bool unconditonally=false ) const;
+
         void removeSelected();
         void clearItems();
 
@@ -152,8 +159,8 @@ class MediaQueue : public KListView, public DropProxyTarget
 
     private:
         void keyPressEvent( QKeyEvent *e );
-
         MediaBrowser *m_parent;
+        mutable KIO::filesize_t m_totalSize;
 };
 
 
@@ -186,6 +193,7 @@ class MediaBrowser : public QVBox
         QString getDisplayPluginName ( const QString string ) { return m_pluginAmarokName[string]; }
         const KTrader::OfferList &getPlugins() { return m_plugins; }
         void transcodingFinished( const QString &src, const QString &dst );
+        bool isTranscoding() const { return m_waitForTranscode; }
         void updateStats();
         void updateButtons();
         void updateDevices();
@@ -287,6 +295,7 @@ class MediaView : public KListView
         void renameItem( QListViewItem *item );
         void slotExpand( QListViewItem* );
         void selectAll() { QListView::selectAll(true); }
+        void invokeItem( QListViewItem*, const QPoint &, int column );
         void invokeItem( QListViewItem* );
 
     private:
@@ -307,7 +316,7 @@ class MediaView : public KListView
    all items are stored in a hierarchy of MediaItems,
    when items are manipulated the MediaItems have to be updated accordingly */
 
-class LIBAMAROK_EXPORT MediaDevice : public QObject, public amaroK::Plugin
+class LIBAMAROK_EXPORT MediaDevice : public QObject, public Amarok::Plugin
 {
     Q_OBJECT
     friend class DeviceConfigureDialog;
