@@ -1,6 +1,7 @@
 /***************************************************************************
  * copyright            : (C) 2006 Ian Monroe <ian@monroe.nu>              *
- **************************************************************************/
+ *                        (C) 2006 Seb Ruiz <me@sebruiz.net>               *
+ ***************************************************************************/
 
 /***************************************************************************
  *                                                                         *
@@ -15,6 +16,8 @@
 #define AMAROK_DAAPCLIENT_CPP
 
 #include "addhostbase.h"
+#include "collectiondb.h"
+#include "collectionbrowser.h"
 #include "daapreader/reader.h"
 #include "daapclient.h"
 #include "daapserver.h"
@@ -23,7 +26,9 @@
 #include "playlist.h"
 #include "proxy.h"
 #include "statusbar/statusbar.h"
+#include "tagdialog.h"
 
+#include <qcheckbox.h>
 #include <qmetaobject.h>
 #include <qobjectlist.h>
 #include <qlabel.h>
@@ -56,24 +61,38 @@ DaapClient::DaapClient()
 #endif
     , m_connected( false )
     , m_sharingServer( 0 )
+    , m_broadcastServerCheckBox( 0 )
+    , m_broadcastServer( false ) // to abide by "all ports closed" policy, we default to not broadcasting music
 {
 DEBUG_BLOCK
     setName( "daapclient" );
     m_name = i18n( "Shared Music" );
-    m_hasMountPoint = false;
+    m_hasMountPoint      = false;
     m_autoDeletePodcasts = false;
-    m_syncStats = false;
-    m_transcode = false;
-    m_transcodeAlways = false;
-    m_transcodeRemove = false;
-    m_configure = false;
-    m_customButton = true;
-    m_transfer = false;
-    KToolBarButton* customButton = MediaBrowser::instance()->getToolBar()->getButton( MediaBrowser::CUSTOM );
+    m_syncStats          = false;
+    m_transcode          = false;
+    m_transcodeAlways    = false;
+    m_transcodeRemove    = false;
+    m_configure          = false;
+    m_customButton       = true;
+    m_transfer           = false;
+
+    KToolBar       *toolbar         = MediaBrowser::instance()->getToolBar();
+    KToolBarButton *customButton    = toolbar->getButton( MediaBrowser::CUSTOM );
     customButton->setText( i18n("Add computer") );
-    QToolTip::add( customButton, i18n( "List music from a remote host" ) );
+
+    toolbar = CollectionBrowser::instance()->getToolBar();
+    toolbar->setIconText( KToolBar::IconTextRight, false );
+    m_broadcastButton = new KToolBarButton( "connect_creating", 0, toolbar, "broadcast_button",
+                                                          i18n("Share My Music") );
+    m_broadcastButton->setToggle( true );
+
+    QToolTip::add( customButton,      i18n( "List music from a remote host" ) );
+    QToolTip::add( m_broadcastButton, i18n( "If this button is checked, then your music will be exported to the network" ) );
+
+    connect( m_broadcastButton, SIGNAL( toggled(int) ), SLOT( broadcastButtonToggled() ) );
+
     MediaBrowser::instance()->insertChild( this );
-    debug() << "lookatme " << (parent() ? parent()->name() : "no parent") << (parent() ? parent()->metaObject()->className() : " ") << endl;
 }
 
 DaapClient::~DaapClient()
@@ -117,8 +136,10 @@ DaapClient::openDevice(bool /* silent=false */)
     {
         m_browser = new DNSSD::ServiceBrowser("_daap._tcp");
         m_browser->setName("daapServiceBrowser");
-        connect( m_browser, SIGNAL( serviceAdded( DNSSD::RemoteService::Ptr ) ), this, SLOT( foundDaap( DNSSD::RemoteService::Ptr ) ) );
-        connect( m_browser, SIGNAL( serviceRemoved( DNSSD::RemoteService::Ptr ) ), this, SLOT( serverOffline( DNSSD::RemoteService::Ptr ) ) );
+        connect( m_browser, SIGNAL( serviceAdded( DNSSD::RemoteService::Ptr ) ),
+                      this,   SLOT( foundDaap   ( DNSSD::RemoteService::Ptr ) ) );
+        connect( m_browser, SIGNAL( serviceRemoved( DNSSD::RemoteService::Ptr ) ),
+                      this,   SLOT( serverOffline ( DNSSD::RemoteService::Ptr ) ) );
         m_browser->startBrowse();
     }
 #endif
@@ -134,8 +155,10 @@ DaapClient::openDevice(bool /* silent=false */)
              newHost( host, host, ip, port );
         }
     }
-    //for 1.4.3 release, comment it out. still doesn't work with iTunes.
-    //m_sharingServer = new DaapServer( this, "DaapServer" );
+
+    if( m_broadcastServer )
+        m_sharingServer = new DaapServer( this, "DaapServer" );
+
     return true;
 }
 
@@ -201,7 +224,7 @@ DaapClient::rmbPressed( QListViewItem* qitem, const QPoint& point, int )
 {
     DEBUG_BLOCK
 
-    enum Actions { APPEND, LOAD, QUEUE, CONNECT, REMOVE };
+    enum Actions { APPEND, LOAD, QUEUE, INFO, CONNECT, REMOVE };
 
     MediaItem *item = dynamic_cast<MediaItem *>(qitem);
     ServerItem* sitem = dynamic_cast<ServerItem *>(qitem);
@@ -217,7 +240,7 @@ DaapClient::rmbPressed( QListViewItem* qitem, const QPoint& point, int )
             menu.insertItem( SmallIconSet( "connect_creating" ), i18n( "&Connect" ), CONNECT );
             if( sitem && !m_serverItemMap.contains( sitem->key() ) )
             {
-                menu.insertItem( SmallIconSet( "delete" ), i18n("&Remove Computer"), REMOVE );
+                menu.insertItem( SmallIconSet( "remove" ), i18n("&Remove Computer"), REMOVE );
             }
             {
                 QStringList sl = m_serverItemMap.keys();
@@ -230,9 +253,16 @@ DaapClient::rmbPressed( QListViewItem* qitem, const QPoint& point, int )
             break;
         default:
             urls = m_view->nodeBuildDragList( 0 );
-            menu.insertItem( SmallIconSet( amaroK::icon( "playlist" ) ), i18n( "&Load" ), LOAD );
-            menu.insertItem( SmallIconSet( amaroK::icon( "add_playlist" ) ), i18n( "&Append to Playlist" ), APPEND );
-            menu.insertItem( SmallIconSet( amaroK::icon( "fastforward" ) ), i18n( "&Queue Tracks" ), QUEUE );
+            menu.insertItem( SmallIconSet( Amarok::icon( "playlist" ) ), i18n( "&Load" ), LOAD );
+            menu.insertItem( SmallIconSet( Amarok::icon( "add_playlist" ) ), i18n( "&Append to Playlist" ), APPEND );
+            menu.insertItem( SmallIconSet( Amarok::icon( "fastforward" ) ), i18n( "&Queue Tracks" ), QUEUE );
+
+            // albums and artists don't have bundles, so they crash... :(
+            if( item->bundle() )
+            {
+                menu.insertSeparator();
+                menu.insertItem( SmallIconSet( Amarok::icon( "info" ) ), i18n( "Track &Information..." ), INFO );
+            }
             break;
     }
 
@@ -240,6 +270,10 @@ DaapClient::rmbPressed( QListViewItem* qitem, const QPoint& point, int )
     switch( id )
     {
         case CONNECT:
+            if( ServerItem *s = dynamic_cast<ServerItem *>(item) )
+            {
+                s->reset();
+            }
             item->setOpen( true );
             break;
         case LOAD:
@@ -251,6 +285,13 @@ DaapClient::rmbPressed( QListViewItem* qitem, const QPoint& point, int )
         case QUEUE:
             Playlist::instance()->insertMedia( urls, Playlist::Queue );
             break;
+        case INFO:
+            {
+                // The tag dialog automatically disables the widgets if the file is not local, which it is not.
+                TagDialog *dialog = new TagDialog( *item->bundle(), 0 );
+                dialog->show();
+            }
+            break;
         case REMOVE:
             if( sitem )
             {
@@ -362,12 +403,19 @@ DaapClient::createTree( const QString& /*host*/, Daap::SongList bundles )
 
             for( track = trackList.first(); track; track = trackList.next() )
             {
+                if( m_removeDuplicates && trackExistsInCollection( track ) )
+                    continue;
                 MediaItem* childTrack = new MediaItem( parentAlbum );
                 childTrack->setText( 0, track->title() );
                 childTrack->setType( MediaItem::TRACK );
                 childTrack->setBundle( track );
+                childTrack->m_order = track->track();
             }
+            if( !parentAlbum->childCount() )
+                delete parentAlbum;
         }
+        if( !parentArtist->childCount() )
+            delete parentArtist;
     }
     root->resetTitle();
     root->stopAnimation();
@@ -406,7 +454,7 @@ DaapClient::customClicked()
                 : KDialogBase( parent, "DaapAddHostDialog", true, i18n( "Add Computer" ) , Ok|Cancel)
             {
                 m_base = new AddHostBase( this, "DaapAddHostBase" );
-                m_base->m_downloadPixmap->setPixmap( QPixmap( KGlobal::iconLoader()->iconPath( amaroK::icon( "download" ), -KIcon::SizeEnormous ) ) );
+                m_base->m_downloadPixmap->setPixmap( QPixmap( KGlobal::iconLoader()->iconPath( Amarok::icon( "download" ), -KIcon::SizeEnormous ) ) );
                 m_base->m_hostName->setFocus();
                 setMainWidget( m_base );
             }
@@ -417,7 +465,7 @@ DaapClient::customClicked()
     if( dialog.exec() == QDialog::Accepted ) {
         QString ip = resolve( dialog.m_base->m_hostName->text() );
         if( ip == "0" )
-            amaroK::StatusBar::instance()->shortMessage( i18n("Could not resolve %1.").arg( dialog.m_base->m_hostName->text() ) );
+            Amarok::StatusBar::instance()->shortMessage( i18n("Could not resolve %1.").arg( dialog.m_base->m_hostName->text() ) );
         else
         {
             QString key = ServerItem::key( dialog.m_base->m_hostName->text(), dialog.m_base->m_portInput->value() );
@@ -493,12 +541,13 @@ QString
 DaapClient::resolve( const QString& hostname )
 {
     KNetwork::KResolver resolver( hostname );
+    resolver.setFamily( KNetwork::KResolver::KnownFamily ); //A druidic incantation from Thiago. Works around a KResolver bug #132851
     resolver.start();
-    if( resolver.wait( 5000 ) ) 
+    if( resolver.wait( 5000 ) )
     {
         KNetwork::KResolverResults results = resolver.results();
         debug() << "Resolver error code (0 is no error): " << resolver.errorString( results.error() ) << ' ' << hostname << endl;
-        if( !results.empty() ) 
+        if( !results.empty() )
         {
             QString ip = results[0].address().asInet().ipAddress().toString();
             debug() << "ip found is " << ip << endl;
@@ -508,6 +557,100 @@ DaapClient::resolve( const QString& hostname )
     return "0"; //error condition
 }
 
+const bool
+DaapClient::trackExistsInCollection( MetaBundle *bundle )
+{
+    /// FIXME slow.
+    QueryBuilder qb;
+    qb.addMatch( QueryBuilder::tabSong  , QueryBuilder::valTitle, bundle->title() , true, false );
+    qb.addMatch( QueryBuilder::tabArtist, QueryBuilder::valName , bundle->artist(), true, false );
+    qb.addMatch( QueryBuilder::tabAlbum , QueryBuilder::valName , bundle->album() , true, false );
+
+    qb.addReturnFunctionValue( QueryBuilder::funcCount, QueryBuilder::tabSong, QueryBuilder::valURL );
+
+    QStringList values = qb.run();
+
+    return ( values[0].toInt() > 0 );
+}
+
+
+/// Configuration Dialog Extension
+
+void
+DaapClient::addConfigElements( QWidget * parent )
+{
+    m_broadcastServerCheckBox = new QCheckBox( "Broadcast my music", parent );
+    m_broadcastServerCheckBox->setChecked( m_broadcastServer );
+
+    m_removeDuplicatesCheckBox = new QCheckBox( "Hide songs in my collection", parent );
+    m_removeDuplicatesCheckBox->setChecked( m_removeDuplicates );
+
+    QToolTip::add( m_removeDuplicatesCheckBox, i18n( "Enabling this may reduce connection times" ) );
+}
+
+
+void
+DaapClient::removeConfigElements( QWidget * /* parent */ )
+{
+    if( m_broadcastServerCheckBox != 0 )
+        delete m_broadcastServerCheckBox;
+
+    if( m_removeDuplicatesCheckBox != 0 )
+        delete m_removeDuplicatesCheckBox;
+
+    m_broadcastServerCheckBox  = 0;
+    m_removeDuplicatesCheckBox = 0;
+}
+
+void
+DaapClient::loadConfig()
+{
+    MediaDevice::loadConfig();
+
+    m_broadcastServer  = configBool( "broadcastServer", false );
+    m_removeDuplicates = configBool( "removeDuplicates", false );
+
+    // don't undo all the work we just did at startup
+    m_broadcastButton->blockSignals( true );
+    m_broadcastButton->setOn( m_broadcastServer );
+    m_broadcastButton->blockSignals( false );
+}
+
+void
+DaapClient::applyConfig()
+{
+    if( m_broadcastServerCheckBox )
+        m_broadcastServer = m_broadcastServerCheckBox->isChecked();
+
+    if( m_removeDuplicatesCheckBox )
+        m_removeDuplicates = m_removeDuplicatesCheckBox->isChecked();
+
+    setConfigBool( "broadcastServer" , m_broadcastServer );
+    setConfigBool( "removeDuplicates", m_removeDuplicates );
+}
+
+void
+DaapClient::broadcastButtonToggled()
+{
+DEBUG_BLOCK
+    debug() << "Chaging server from " << m_broadcastServer << " to " << !m_broadcastServer << endl;
+    m_broadcastServer = !m_broadcastServer;
+
+    switch( m_broadcastServer )
+    {
+        case false:
+            if( m_sharingServer )
+                delete m_sharingServer;
+            m_sharingServer = 0;
+            break;
+
+        case true:
+            if( !m_sharingServer )
+                m_sharingServer = new DaapServer( this, "DaapServer" );
+            break;
+    }
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // CLASS ServerItem
 ////////////////////////////////////////////////////////////////////////////////
@@ -534,6 +677,23 @@ ServerItem::~ServerItem()
     m_reader = 0;
 }
 
+void
+ServerItem::reset()
+{
+    delete m_reader;
+    m_reader = 0;
+
+    m_loaded = 0;
+
+    QListViewItem *c = firstChild();
+    QListViewItem *n;
+    while( c ) {
+        n = c->nextSibling();
+        delete c;
+        c = n;
+    }
+}
+
 void
 ServerItem::setOpen( bool o )
 {
@@ -596,7 +756,7 @@ ServerItem::httpError( const QString& errorString )
 {
     stopAnimation();
     resetTitle();
-    amaroK::StatusBar::instance()->longMessage( i18n( "The following error occured while trying to connect to the remote server:<br>%1").arg( errorString ) );
+    Amarok::StatusBar::instance()->longMessage( i18n( "The following error occurred while trying to connect to the remote server:<br>%1").arg( errorString ) );
     m_reader->deleteLater();
     m_reader = 0;
     m_loaded = false;
