@@ -17,7 +17,6 @@
 #include <taglib/audioproperties.h>
 #include "expression.h"
 #include "atomicstring.h"
-#include "atomicurl.h"
 #include "moodbar.h"
 
 #include "amarok_export.h"
@@ -97,12 +96,17 @@ public:
         QByteArray m_data;
         QString m_description;
         mutable QCString m_hash;
-    };
+   };
 
     typedef QValueList<EmbeddedImage> EmbeddedImageList;
 
+    /** This is a bit vector for selecting columns. It's very fast to compare
+        in matchFast. It might be a good idea to replace the QValue<int>
+        column masks with this eventually. */
+    typedef Q_UINT32 ColumnMask;
+
     /** Returns the name of the column at \p index as a string -- not i18ned, for internal purposes. */
-    static const QString exactColumnName( int index );
+    static const QString &exactColumnName( int index );
     /** Returns the name of the column at \p index as a string -- i18ned, for display purposes. */
     static const QString prettyColumnName( int index );
     /** Returns the index of the column with the not i18ned name \p name. */
@@ -169,10 +173,17 @@ public:
     bool save( TagLib::FileRef* fileref = 0 );
 
     /** Saves the MetaBundle's data as XML to a text stream. */
-    bool save( QTextStream &stream, const QStringList &attributes = QStringList(), int indent = 0 ) const;
+    bool save( QTextStream &stream, const QStringList &attributes = QStringList() ) const;
 
+    /** Returns whether the url referred to is a local file */
     bool isFile() const;
 
+    /** Returns whether the url referred to can be accessed via kio slaves */
+    bool isKioUrl() const;
+
+    /** Returns whether url can be accessed via kio slaves */
+    static bool isKioUrl( const KURL &url );
+
     /** Returns whether composer, disc number and bpm fields are available. */
     bool hasExtendedMetaInformation() const;
 
@@ -198,6 +209,15 @@ public:
         @see ExpressionParser::isAdvancedExpression() */
     bool matchesSimpleExpression( const QString &expression, const QValueList<int> &columns ) const;
 
+    /** A faster version of the above, that pre-caches all the data to be
+        searched in a single string, to avoid re-building integer and lower
+        case strings over and over. It is designed to be called from a
+        playlist search *only* -- it is not entirely thread-safe for efficiency,
+        although it's highly unlikely to crash. Consider this the beginning
+        of a real super-efficient index (e.g. suffix tree).
+        \p terms is a list of lower-case words. */
+    bool matchesFast(const QStringList &terms, ColumnMask columns) const;
+
     /** Returns whether the bundle matches \p expression.
         This takes advanced syntax into account, and is slightly slower than matchesSimpleExpression().
         The tags in \p defaultColumns are checked for matches where the expression doesn't specify any manually. */
@@ -210,7 +230,7 @@ public:
 
     /** PlaylistItem reimplements this so it can be informed of moodbar
         data events without having to use signals */
-    virtual void moodbarJobEvent( int newState ) 
+    virtual void moodbarJobEvent( int newState )
         { (void) newState; }
 
 public:
@@ -221,7 +241,7 @@ public:
     class XmlLoader;
 
 public: //accessors
-    KURL url()               const;
+    const KURL &url()               const;
     QString      title()     const;
     AtomicString artist()    const;
     AtomicString composer()  const;
@@ -302,7 +322,8 @@ public: //modifiers
     void setLastFmBundle( const LastFm::Bundle &last );
     void setUniqueId(); //uses database for lookup
     void setUniqueId( const QString &id ); //SEE COMMENT in .CPP
-    QString readUniqueId();
+    const TagLib::ByteVector readUniqueIdHelper( TagLib::FileRef fileref ) const;
+    QString readUniqueId( TagLib::FileRef *fileref = 0  );
     void scannerAcknowledged() {}
 
     void detach(); // for being able to apply QDeepCopy<>
@@ -337,7 +358,6 @@ protected:
     void reactToChange( int column );
 
     KURL m_url;
-//     AtomicURL m_url;
     QString m_title;
     AtomicString m_artist;
     AtomicString m_composer;
@@ -380,6 +400,18 @@ protected:
     PodcastEpisodeBundle *m_podcastBundle;
     LastFm::Bundle *m_lastFmBundle;
 
+    // The vars below are used to optimize search by storing
+    // the full text to be searched. They are mutable, as they
+    // act like a sort of cache for the const method matchesFast
+
+    // whether the search text should be rebuilt
+    volatile mutable bool m_isSearchDirty;
+    // which columns the search string contains
+    mutable ColumnMask m_searchColumns;
+    // the search string: textualized columns separated by space
+    // note that matchFast searches by words, hence a word cannot span
+    // space-separated columns
+    mutable QString m_searchStr;
 private:
 
     static inline QString prettyGeneric( const QString &s, const int i )
@@ -415,12 +447,13 @@ inline bool MetaBundle::audioPropertiesUndetermined() const
 
 inline void MetaBundle::aboutToChange( const QValueList<int>& ) { }
 inline void MetaBundle::aboutToChange( int column ) { aboutToChange( QValueList<int>() << column ); }
-inline void MetaBundle::reactToChanges( const QValueList<int>& ) { }
 inline void MetaBundle::reactToChange( int column ) { reactToChanges( QValueList<int>() << column ); }
 
 inline bool MetaBundle::exists() const { return m_exists; }
 
 inline bool MetaBundle::isFile() const { return url().isLocalFile(); }
+inline bool MetaBundle::isKioUrl() const { return isKioUrl( url() ); }
+inline bool MetaBundle::isKioUrl( const KURL &url ) { return url.protocol() != "daap" && url.protocol() != "cdda" && url.protocol() != "lastfm"; }
 
 inline int MetaBundle::track()      const { return m_track == Undetermined ? 0 : m_track; }
 inline int MetaBundle::year()       const { return m_year  == Undetermined ? 0 : m_year; }
@@ -430,21 +463,21 @@ inline int MetaBundle::sampleRate() const { return m_sampleRate == Undetermined
 inline int MetaBundle::filesize()   const { return m_filesize == Undetermined ? 0 : m_filesize; }
 inline int MetaBundle::fileType()   const { return m_type; }
 
-inline Moodbar &MetaBundle::moodbar() 
+inline Moodbar &MetaBundle::moodbar()
 {
-  if( m_moodbar == 0 ) m_moodbar = new Moodbar( this ); 
-  return *m_moodbar; 
+  if( m_moodbar == 0 ) m_moodbar = new Moodbar( this );
+  return *m_moodbar;
 }
 inline const Moodbar &MetaBundle::moodbar_const() const
 {
   // Anyone know of a better way to do this?
-  if( m_moodbar == 0 ) 
-    const_cast<MetaBundle*>(this)->m_moodbar 
-      = new Moodbar( const_cast<MetaBundle*>(this) ); 
-  return *m_moodbar; 
+  if( m_moodbar == 0 )
+    const_cast<MetaBundle*>(this)->m_moodbar
+      = new Moodbar( const_cast<MetaBundle*>(this) );
+  return *m_moodbar;
 }
 
-inline KURL     MetaBundle::url()        const { return m_url; }
+inline const KURL&     MetaBundle::url()        const { return m_url; }
 inline QString  MetaBundle::filename()   const { return url().fileName(); }
 inline QString  MetaBundle::directory()  const
 {
