@@ -50,7 +50,7 @@
 
 #define NEARBYINT(i) ((int(float(i) + 0.5)))
 
-namespace amaroK { extern KConfig *config( const QString& ); }
+namespace Amarok { extern KConfig *config( const QString& ); }
 
 class MultiTabBarTabPrivate
 {
@@ -168,14 +168,10 @@ void MultiTabBarInternal::contentsMousePressEvent( QMouseEvent *ev )
     ev->ignore();
 }
 
-void MultiTabBarInternal::mousePressEvent( QMouseEvent *ev )
-{
-    if ( ev->button() != QMouseEvent::RightButton ){
-        ev->ignore();
-        return;
-    }
 
-    // right button pressed
+void MultiTabBarInternal::showTabSelectionMenu(QPoint pos)
+{
+
     KPopupMenu popup;
     popup.insertTitle(  i18n("Browsers") , /*id*/ -1, /*index*/ 1 );
     popup.setCheckable( true );
@@ -185,9 +181,22 @@ void MultiTabBarInternal::mousePressEvent( QMouseEvent *ev )
         popup.setItemChecked(i, tab->visible() ? true : false);
     }
 
-    int col = popup.exec( static_cast<QMouseEvent *>(ev)->globalPos() );
+    int col = popup.exec(pos);
     if ( col >= 0 )
         setTabVisible( col, !popup.isItemChecked(col) );
+
+}
+
+void MultiTabBarInternal::mousePressEvent( QMouseEvent *ev )
+{
+    if ( ev->button() != QMouseEvent::RightButton ){
+        ev->ignore();
+        return;
+    }
+
+    // right button pressed
+    showTabSelectionMenu(ev->globalPos());
+
 }
 
 
@@ -212,6 +221,7 @@ void MultiTabBarInternal::resizeEvent( QResizeEvent *ev )
     /*  kdDebug()<<"MultiTabBarInternal::resizeEvent"<<endl;
         kdDebug()<<"MultiTabBarInternal::resizeEvent - box geometry"<<box->geometry()<<endl;
         kdDebug()<<"MultiTabBarInternal::resizeEvent - geometry"<<geometry()<<endl;*/
+
     if ( ev ) QScrollView::resizeEvent( ev );
 
     if ( ( m_style == MultiTabBar::KDEV3 ) ||
@@ -224,7 +234,7 @@ void MultiTabBarInternal::resizeEvent( QResizeEvent *ev )
         if ( ( m_position == MultiTabBar::Bottom ) || ( m_position == MultiTabBar::Top ) )
             space = width();
         else
-            space = height();
+            space = height(); // made space for tab management button
 
         int cnt = 0;
         //CALCULATE LINES
@@ -400,13 +410,14 @@ bool MultiTabBarInternal::eventFilter( QObject *, QEvent *e )
     return false;
 }
 
-int MultiTabBarInternal::appendTab( const QPixmap &pic , int id, const QString& text )
+int MultiTabBarInternal::appendTab( const QPixmap &pic , int id, const QString& text, const QString& identifier )
 {
     MultiTabBarTab * tab;
     m_tabs.append( tab = new MultiTabBarTab( pic, text, id, box, m_position, m_style ) );
+    tab->setIdentifier( identifier );
     tab->installEventFilter( this );
     tab->showActiveTabText( m_showActiveTabTexts );
-    tab->setVisible( amaroK::config( "BrowserBar" )->readBoolEntry( text, true ) );
+    tab->setVisible( Amarok::config( "BrowserBar" )->readBoolEntry( identifier, true ) );
 
     if ( m_style == MultiTabBar::KONQSBC ) {
         if ( m_expandedTabSize < tab->neededSize() ) {
@@ -443,7 +454,7 @@ void MultiTabBarInternal::setTabVisible( int id, bool visible )
             MultiTabBarTab* tab = m_tabs.at( pos );
 
             tab->setVisible( visible );
-            amaroK::config( "BrowserBar" )->writeEntry( tab->text(), tab->visible() );
+            Amarok::config( "BrowserBar" )->writeEntry( tab->identifier(), tab->visible() );
 
             if ( tab->visible() )
                 tab->show();
@@ -486,9 +497,9 @@ uint MultiTabBarInternal::visibleTabCount()
 uint MultiTabBarInternal::sizePerTab()
 {
     uint size;
-
     if( m_position == MultiTabBar::Left || m_position == MultiTabBar::Right )
-        size = (height() - 3 ) / visibleTabCount();
+                        /* HACK: width() is the "Manage Tabs" button size :-( */
+        size = (height() - 3 - width() ) / visibleTabCount();
     else
         size = (width() - 3 ) / visibleTabCount();
 
@@ -717,6 +728,7 @@ MultiTabBarTab::MultiTabBarTab( const QPixmap& pic, const QString& text,
 {
     d = new MultiTabBarTabPrivate();
     setIcon( pic );
+    setIdentifier( text );
     m_expandedSize = 24;
     setToggleButton( true );
 
@@ -1189,9 +1201,9 @@ void MultiTabBar::updateSeparator()
 
 }
 
-int MultiTabBar::appendTab( const QPixmap &pic , int id , const QString& text )
+int MultiTabBar::appendTab( const QPixmap &pic , int id , const QString& text, const QString& identifier )
 {
-    m_internal->appendTab( pic, id, text );
+    m_internal->appendTab( pic, id, text, identifier );
     return 0;
 }
 
@@ -1284,3 +1296,8 @@ void MultiTabBar::fontChange( const QFont& /* oldFont */ )
 QPtrList<MultiTabBarTab>* MultiTabBar::tabs() { return m_internal->tabs();}
 QPtrList<MultiTabBarButton>* MultiTabBar::buttons() { return & m_buttons;}
 
+void MultiTabBar::showTabSelectionMenu(QPoint pos)
+{
+    m_internal->showTabSelectionMenu(pos);
+}
+
