@@ -44,10 +44,17 @@ class PlaylistBrowser : public QVBox
         Q_OBJECT
     friend class DynamicMode;
     friend class PlaylistBrowserView;
+
     friend class PlaylistBrowserEntry;
     friend class PlaylistCategory;
     friend class PlaylistEntry;
+    friend class PlaylistTrackItem;
     friend class PodcastChannel;  //for changing podcast timer list
+    friend class PodcastEpisode;
+    friend class DynamicEntry;
+    friend class StreamEntry;
+    friend class SmartPlaylist;
+
 
     public:
         enum AddMode  { PLAYLIST, PLAYLIST_IMPORT, STREAM, SMARTPLAYLIST, PODCAST, ADDDYNAMIC };
@@ -83,7 +90,7 @@ class PlaylistBrowser : public QVBox
         QListViewItem *findItemInTree( const QString &searchstring, int c ) const;
         PodcastEpisode *findPodcastEpisode( const KURL &episode, const KURL &feed ) const;
 
-        QPtrList<QListViewItem> dynamicEntries() const { return m_dynamicEntries; }
+        QPtrList<PlaylistBrowserEntry> dynamicEntries() const { return m_dynamicEntries; }
         DynamicMode *findDynamicModeByTitle( const QString &title );
         QListViewItem *podcastCategory() const { return m_podcastCategory; }
 
@@ -109,7 +116,8 @@ class PlaylistBrowser : public QVBox
 
     private slots:
         void abortPodcastQueue();
-        void addToDynamic();
+        void addSelectedToDynamic();
+        void addToDynamic( QListViewItem *item );
         void addSelectedToPlaylist( int options = -1 );
         void collectionScanDone();
         void currentItemChanged( QListViewItem * );
@@ -118,11 +126,12 @@ class PlaylistBrowser : public QVBox
         void removeSelectedItems();
         void renamePlaylist( QListViewItem*, const QString&, int );
         void renameSelectedItem();
+        void invokeItem( QListViewItem*, const QPoint &, int column );
         void slotDoubleClicked( QListViewItem *item );
-        void subFromDynamic();
+        void subSelectedFromDynamic();
+        void subFromDynamic( QListViewItem *item );
 
         void slotAddMenu( int id );
-        void slotSave();
         void showContextMenu( QListViewItem*, const QPoint&, int );
 
         void loadDynamicItems();
@@ -150,6 +159,8 @@ class PlaylistBrowser : public QVBox
         void updateSmartPlaylistElement( QDomElement& query );
 
         PlaylistCategory* loadDynamics();
+        void fixDynamicPlaylistPath( QListViewItem *item );
+        QString guessPathFromPlaylistName( QString name );
 
         PlaylistCategory* loadPodcasts();
         QMap<int,PlaylistCategory*> loadPodcastFolders( PlaylistCategory *p );
@@ -165,6 +176,9 @@ class PlaylistBrowser : public QVBox
         void savePodcastFolderStates( PlaylistCategory *folder );
         PodcastChannel *findPodcastChannel( const KURL &feed, QListViewItem *parent=0 ) const;
 
+        void markDynamicEntries();
+        PlaylistBrowserEntry* findByName( QString name );
+
         PlaylistCategory* loadPlaylists();
         void savePlaylists();
         void savePlaylist( PlaylistEntry * );
@@ -186,7 +200,6 @@ class PlaylistBrowser : public QVBox
         PlaylistCategory    *m_smartCategory;
         PlaylistCategory    *m_dynamicCategory;
         PlaylistCategory    *m_podcastCategory;
-        PlaylistCategory    *m_playlistImports;
         PlaylistCategory    *m_coolStreams;
         PlaylistCategory    *m_smartDefaults;
         PlaylistCategory    *m_lastfmCategory;
@@ -209,7 +222,7 @@ class PlaylistBrowser : public QVBox
         QValueList<int>      m_dynamicSizeSave;
 
         QDict<PodcastSettings>   m_podcastSettings;
-        QPtrList<QListViewItem>  m_dynamicEntries;
+        QPtrList<PlaylistBrowserEntry>  m_dynamicEntries;
 
         QTimer                  *m_podcastTimer;
         int                      m_podcastTimerInterval;        //in ms
