@@ -50,8 +50,9 @@ struct XMLData
     MetaBundle bundle;
     int queue;
     bool stopafter;
-    bool disabled;
-    XMLData(): queue(-1), stopafter(false), disabled(false) { }
+    bool dynamicdisabled;
+    bool filestatusdisabled;
+    XMLData(): queue(-1), stopafter(false), dynamicdisabled(false), filestatusdisabled(false) { }
 };
 
 class TagsEvent : public QCustomEvent {
@@ -86,18 +87,18 @@ UrlLoader::UrlLoader( const KURL::List &urls, QListViewItem *after, bool playFir
 
     Playlist::instance()->lock(); // prevent user removing items as this could be bad
 
-    amaroK::OverrideCursor cursor;
+    Amarok::OverrideCursor cursor;
 
     setDescription( i18n("Populating playlist") );
 
-    amaroK::StatusBar::instance()->newProgressOperation( this )
+    Amarok::StatusBar::instance()->newProgressOperation( this )
             .setDescription( m_description )
             .setStatus( i18n("Preparing") )
             .setAbortSlot( this, SLOT(abort()) )
             .setTotalSteps( 100 );
 
     foreachType( KURL::List, urls ) {
-        const KURL &url = *it;
+        const KURL url = Amarok::mostLocalURL( *it );
         // FIXME: url needs detach()ing
         const QString protocol = url.protocol();
 
@@ -229,7 +230,7 @@ UrlLoader::customEvent( QCustomEvent *e)
             {
                 //Since ATF's read-only functions will now always be on, always use the ATF
                 //behavior...add anyways, but disable, we expect to find with an update
-                /*PlaylistItem *item = */ new PlaylistItem( *it, m_markerListViewItem, false );
+                new PlaylistItem( *it, m_markerListViewItem, false );
             }
             else
             {
@@ -274,8 +275,10 @@ UrlLoader::customEvent( QCustomEvent *e)
             if( (*it).stopafter )
                 Playlist::instance()->m_stopAfterTrack = item;
 
-            if( (*it).disabled || !( (*it).bundle.exists() ) )
-                item->setEnabled( false );
+            if( (*it).filestatusdisabled || !( (*it).bundle.exists() ) )
+                item->setFilestatusEnabled( false );
+            if( (*it).dynamicdisabled )
+                item->setDynamicEnabled( false );
         }
         break;
     }
@@ -313,7 +316,7 @@ UrlLoader::completeJob()
             debug() << "\t" << m_badURLs[it] << endl;
         }
 
-        amaroK::StatusBar::instance()->shortLongMessage(
+        Amarok::StatusBar::instance()->shortLongMessage(
                 i18n("Some media could not be loaded (not playable)."), text );
     }
 
@@ -361,7 +364,7 @@ UrlLoader::recurse( const KURL &url )
     return urls;
 }
 
-namespace amaroK
+namespace Amarok
 {
 
 // almost the same as UrlLoader::recurse, but global
@@ -427,7 +430,7 @@ recursiveUrlExpand( const KURL::List &list, int maxURLs )
     return urls;
 }
 
-} // amaroK
+} // Amarok
 
 void
 UrlLoader::loadXml( const KURL &url )
@@ -454,7 +457,7 @@ UrlLoader::loadXml( const KURL &url )
     }
     if( !loader.lastError().isEmpty() )
     {
-        amaroK::StatusBar::instance()->longMessageThreadSafe( i18n(
+        Amarok::StatusBar::instance()->longMessageThreadSafe( i18n(
                 //TODO add a link to the path to the playlist
                 "The XML in the playlist was invalid. Please report this as a bug to the Amarok "
                 "developers. Thank you." ), KDE::StatusBar::Error );
@@ -477,8 +480,10 @@ void UrlLoader::slotNewBundle( const MetaBundle &bundle, const XmlAttributeList
         }
         else if( atts[i].first == "stop_after" )
             data.stopafter = true;
-        else if( atts[i].first == "disabled" )
-            data.disabled = true;
+        else if( atts[i].first == "dynamicdisabled" )
+            data.dynamicdisabled = true;
+        else if( atts[i].first == "filestatusdisabled" )
+            data.filestatusdisabled = true;
     }
     data.bundle.checkExists();
     m_xml.append( data );
@@ -491,9 +496,9 @@ void UrlLoader::slotNewBundle( const MetaBundle &bundle, const XmlAttributeList
 
 void UrlLoader::slotPlaylistInfo( const QString &, const QString &version, const QString &dynamicMode )
 {
-    if( version != amaroK::xmlVersion() )
+    if( version != Amarok::xmlVersion() )
     {
-        amaroK::StatusBar::instance()->longMessageThreadSafe( i18n(
+        Amarok::StatusBar::instance()->longMessageThreadSafe( i18n(
             "Your last playlist was saved with a different version of Amarok than this one, "
             "and this version can no longer read it.\n"
             "You will have to create a new one.\n"
@@ -957,7 +962,7 @@ RemotePlaylistFetcher::RemotePlaylistFetcher( const KURL &source, QListViewItem
             false,   /* resume download */
             false ); /* don't show stupid UIServer dialog */
 
-    amaroK::StatusBar::instance()->newProgressOperation( job )
+    Amarok::StatusBar::instance()->newProgressOperation( job )
             .setDescription( i18n("Retrieving Playlist") );
 
     connect( job, SIGNAL(result( KIO::Job* )), SLOT(result( KIO::Job* )) );
@@ -1000,7 +1005,11 @@ RemotePlaylistFetcher::result( KIO::Job *job )
 SqlLoader::SqlLoader( const QString &sql, QListViewItem *after )
         : UrlLoader( KURL::List(), after, false )
         , m_sql( QDeepCopy<QString>( sql ) )
-{}
+{
+    // Ovy: just until we make sure every SQL query from dynamic playlists is handled
+    // correctly
+    debug() << "Sql loader: query is: " << sql << "\n";
+}
 
 bool
 SqlLoader::doJob()
