@@ -64,12 +64,15 @@ class PlaylistWindow : public QWidget, public KXMLGUIClient
         //instance is declared in KXMLGUI
         static PlaylistWindow *self() { return s_instance; }
 
+        void activate();
+
     public slots:
         void showHide();
         void mbAvailabilityChanged( bool isAvailable );
 
     private slots:
         void savePlaylist() const;
+        void slotBurnPlaylist() const;
         void slotPlayMedia();
         void slotAddLocation( bool directPlay = false );
         void slotAddStream();
