@@ -13,6 +13,9 @@ email                : markey@web.de
  *                                                                         *
  ***************************************************************************/
 
+#define DEBUG_PREFIX "PluginManager"
+
+#include "debug.h"
 #include "plugin.h"
 #include "pluginmanager.h"
 
@@ -21,21 +24,14 @@ email                : markey@web.de
 #include <qfile.h>
 #include <qstring.h>
 
-#include <kdebug.h>
 #include <klibloader.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 
-using namespace std;
-using amaroK::Plugin;
+using std::vector;
+using Amarok::Plugin;
 
 
-static inline kdbgstream
-debug()
-{
-    return kdbgstream( "[PluginManager] ", 0, 0 );
-}
-
 vector<PluginManager::StoreItem>
 PluginManager::m_store;
 
@@ -49,26 +45,28 @@ PluginManager::query( const QString& constraint )
 {
     // Add versioning constraint
     QString
-    str  = "[X-KDE-amaroK-framework-version] == ";
+    str  = "[X-KDE-Amarok-framework-version] == ";
     str += QString::number( FrameworkVersion );
+    if ( !constraint.stripWhiteSpace().isEmpty() )
+        str += " and " + constraint;
     str += " and ";
-    str += constraint;
-    str += " and ";
-    str += "[X-KDE-amaroK-rank] > 0";
+    str += "[X-KDE-Amarok-rank] > 0";
 
     debug() << "Plugin trader constraint: " << str << endl;
 
-    return KTrader::self()->query( "amaroK/Plugin", str );
+    return KTrader::self()->query( "Amarok/Plugin", str );
 }
 
 
 Plugin*
 PluginManager::createFromQuery( const QString &constraint )
 {
+    Debug::Block block( __PRETTY_FUNCTION__ );
+
     KTrader::OfferList offers = query( constraint );
 
     if ( offers.isEmpty() ) {
-        kdWarning() << k_funcinfo << "No matching plugin found.\n";
+        warning() << k_funcinfo << "No matching plugin found.\n";
         return 0;
     }
 
@@ -76,7 +74,7 @@ PluginManager::createFromQuery( const QString &constraint )
     int rank = 0;
     uint current = 0;
     for ( uint i = 0; i < offers.count(); i++ ) {
-        if ( offers[i]->property( "X-KDE-amaroK-rank" ).toInt() > rank )
+        if ( offers[i]->property( "X-KDE-Amarok-rank" ).toInt() > rank )
             current = i;
     }
 
@@ -105,7 +103,7 @@ PluginManager::createFromService( const KService::Ptr service )
     Plugin* (*create_plugin)() = ( Plugin* (*)() ) lib->symbol( "create_plugin" );
 
     if ( !create_plugin ) {
-        kdWarning() << k_funcinfo << "create_plugin == NULL\n";
+        warning() << k_funcinfo << "create_plugin == NULL\n";
         return 0;
     }
     //create plugin on the heap
@@ -126,7 +124,7 @@ PluginManager::createFromService( const KService::Ptr service )
 void
 PluginManager::unload( Plugin* plugin )
 {
-    kdDebug() << k_funcinfo << endl;
+    DEBUG_FUNC_INFO
 
     vector<StoreItem>::iterator iter = lookupPlugin( plugin );
 
@@ -138,7 +136,7 @@ PluginManager::unload( Plugin* plugin )
         m_store.erase( iter );
     }
     else
-        kdWarning() << k_funcinfo << "Could not unload plugin (not found in store).\n";
+        warning() << k_funcinfo << "Could not unload plugin (not found in store).\n";
 }
 
 
@@ -146,7 +144,7 @@ KService::Ptr
 PluginManager::getService( const Plugin* plugin )
 {
     if ( !plugin ) {
-        kdWarning() << k_funcinfo << "pointer == NULL\n";
+        warning() << k_funcinfo << "pointer == NULL\n";
         return 0;
     }
 
@@ -154,7 +152,7 @@ PluginManager::getService( const Plugin* plugin )
     vector<StoreItem>::const_iterator iter = lookupPlugin( plugin );
 
     if ( iter == m_store.end() )
-        kdWarning() << k_funcinfo << "Plugin not found in store.\n";
+        warning() << k_funcinfo << "Plugin not found in store.\n";
 
     return (*iter).service;
 }
@@ -164,6 +162,10 @@ void
 PluginManager::showAbout( const QString &constraint )
 {
     KTrader::OfferList offers = query( constraint );
+
+    if ( offers.isEmpty() )
+        return;
+
     KService::Ptr s = offers.front();
 
     const QString body = "<tr><td>%1</td><td>%2</td></tr>";
@@ -172,10 +174,10 @@ PluginManager::showAbout( const QString &constraint )
 
     str += body.arg( i18n( "Name" ),                s->name() );
     str += body.arg( i18n( "Library" ),             s->library() );
-    str += body.arg( i18n( "Authors" ),             s->property( "X-KDE-amaroK-authors" ).toStringList().join( "\n" ) );
-    str += body.arg( i18n( "Email" ),               s->property( "X-KDE-amaroK-email" ).toStringList().join( "\n" ) );
-    str += body.arg( i18n( "Version" ),             s->property( "X-KDE-amaroK-version" ).toString() );
-    str += body.arg( i18n( "Framework Version" ),   s->property( "X-KDE-amaroK-framework-version" ).toString() );
+    str += body.arg( i18n( "Authors" ),             s->property( "X-KDE-Amarok-authors" ).toStringList().join( "\n" ) );
+    str += body.arg( i18n( "Email" ),               s->property( "X-KDE-Amarok-email" ).toStringList().join( "\n" ) );
+    str += body.arg( i18n( "Version" ),             s->property( "X-KDE-Amarok-version" ).toString() );
+    str += body.arg( i18n( "Framework Version" ),   s->property( "X-KDE-Amarok-framework-version" ).toString() );
 
     str += "</table></body></html>";
 
@@ -186,21 +188,25 @@ PluginManager::showAbout( const QString &constraint )
 void
 PluginManager::dump( const KService::Ptr service )
 {
-    kdbgstream d( 0, 0 );
+    #define ENDLI endl << Debug::indent()
 
-    d << endl
-      << "PluginManager Service Info:\n"
-      << "---------------------------\n"
-      << "name                          : " << service->name() << endl
-      << "library                       : " << service->library() << endl
-      << "desktopEntryPath              : " << service->desktopEntryPath() << endl
-      << "X-KDE-amaroK-plugintype       : " << service->property( "X-KDE-amaroK-plugintype" ).toString() << endl
-      << "X-KDE-amaroK-name             : " << service->property( "X-KDE-amaroK-name" ).toString() << endl
-      << "X-KDE-amaroK-authors          : " << service->property( "X-KDE-amaroK-authors" ).toStringList() << endl
-      << "X-KDE-amaroK-rank             : " << service->property( "X-KDE-amaroK-rank" ).toString() << endl
-      << "X-KDE-amaroK-version          : " << service->property( "X-KDE-amaroK-version" ).toString() << endl
-      << "X-KDE-amaroK-framework-version: " << service->property( "X-KDE-amaroK-framework-version" ).toString() << endl
+    kdDebug()
+      << ENDLI
+      << "PluginManager Service Info:" << ENDLI
+      << "---------------------------" << ENDLI
+      << "name                          : " << service->name() << ENDLI
+      << "library                       : " << service->library() << ENDLI
+      << "desktopEntryPath              : " << service->desktopEntryPath() << ENDLI
+      << "X-KDE-Amarok-plugintype       : " << service->property( "X-KDE-Amarok-plugintype" ).toString() << ENDLI
+      << "X-KDE-Amarok-name             : " << service->property( "X-KDE-Amarok-name" ).toString() << ENDLI
+      << "X-KDE-Amarok-authors          : " << service->property( "X-KDE-Amarok-authors" ).toStringList() << ENDLI
+      << "X-KDE-Amarok-rank             : " << service->property( "X-KDE-Amarok-rank" ).toString() << ENDLI
+      << "X-KDE-Amarok-version          : " << service->property( "X-KDE-Amarok-version" ).toString() << ENDLI
+      << "X-KDE-Amarok-framework-version: " << service->property( "X-KDE-Amarok-framework-version" ).toString()
+      << endl
       << endl;
+
+    #undef ENDLI
 }
 
 
@@ -214,7 +220,8 @@ PluginManager::lookupPlugin( const Plugin* plugin )
     vector<StoreItem>::iterator iter;
 
     //search plugin pointer in store
-    for ( iter = m_store.begin(); iter != m_store.end(); iter++ ) {
+    vector<StoreItem>::iterator iterEnd(m_store.end() );
+    for ( iter = m_store.begin(); iter != iterEnd; ++iter ) {
         if ( (*iter).plugin == plugin )
             break;
     }
