@@ -24,6 +24,8 @@
 #include "collectiondb.h"
 #include "debug.h"
 #include "metabundle.h"
+#include "mountpointmanager.h"
+#include "playlist.h"
 #include "playlistbrowser.h"
 #include "scancontroller.h"
 #include "statusbar.h"
@@ -32,54 +34,44 @@
 #include <qfileinfo.h>
 #include <qtextcodec.h>
 
+#include <dcopref.h>
 #include <kapplication.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kprocio.h>
-
-
-////////////////////////////////////////////////////////////////////////////////
-// class ScannerProcIO
-////////////////////////////////////////////////////////////////////////////////
-/**
- * Due to xine-lib, we have to make KProcess close all fds, otherwise we get "device is busy" messages
- * Used by AmaroKProcIO and AmaroKProcess, exploiting commSetupDoneC(), a virtual method that
- * happens to be called in the forked process
- * See bug #103750 for more information.
- */
-class ScannerProcIO : public KProcIO {
-    public:
-    ScannerProcIO();
-    virtual int commSetupDoneC() {
-        const int i = KProcIO::commSetupDoneC();
-        amaroK::closeOpenFiles( KProcIO::out[0],KProcIO::in[0],KProcIO::err[0] );
-        return i;
-    };
-};
-
-/**
- * This constructor is needed so that the correct codec is used. KProcIO defaults
- * to latin1, while the scanner uses UTF-8.
- */
-ScannerProcIO::ScannerProcIO() : KProcIO( QTextCodec::codecForName( "UTF-8" ) ) {}
-
 
 ////////////////////////////////////////////////////////////////////////////////
 // class ScanController
 ////////////////////////////////////////////////////////////////////////////////
 
+ScanController* ScanController::currController = 0;
+
+ScanController* ScanController::instance()
+{
+    return currController;
+}
+
+void ScanController::setInstance( ScanController* curr )
+{
+    currController = curr;
+}
+
 ScanController::ScanController( CollectionDB* parent, bool incremental, const QStringList& folders )
     : DependentJob( parent, "CollectionScanner" )
     , QXmlDefaultHandler()
-    , m_scanner( new ScannerProcIO() )
+    , m_scanner( new Amarok::ProcIO() )
     , m_folders( QDeepCopy<QStringList>( folders ) )
     , m_incremental( incremental )
     , m_hasChanged( false )
     , m_source( new QXmlInputSource() )
     , m_reader( new QXmlSimpleReader() )
+    , m_waitingBundle( 0 )
+    , m_lastCommandPaused( false )
+    , m_isPaused( false )
+    , m_tablesCreated( false )
 {
     DEBUG_BLOCK
 
+    ScanController::setInstance( this );
     m_reader->setContentHandler( this );
     m_reader->parse( m_source, true );
 
@@ -127,6 +119,37 @@ ScanController::~ScanController()
     delete m_scanner;
     delete m_reader;
     delete m_source;
+    ScanController::setInstance( 0 );
+}
+
+
+// Cause the CollectionDB to emit fileDeleted() signals
+void
+ScanController::completeJob( void )
+{
+    m_fileMapsMutex.lock();
+
+    QMap<QString,QString>::Iterator it;
+    if( !m_incremental )
+    {
+        CollectionDB::instance()->emitFilesAdded( m_filesAdded );
+    }
+    else
+    {
+        for( it = m_filesAdded.begin(); it != m_filesAdded.end(); ++it )
+        {
+            if( m_filesDeleted.contains( it.key() ) )
+                m_filesDeleted.remove( it.key() );
+        }
+        for( it = m_filesAdded.begin(); it != m_filesAdded.end(); ++it )
+            CollectionDB::instance()->emitFileAdded( it.data(), it.key() );
+        for( it = m_filesDeleted.begin(); it != m_filesDeleted.end(); ++it )
+            CollectionDB::instance()->emitFileDeleted( it.data(), it.key() );
+    }
+
+    m_fileMapsMutex.unlock();
+
+    ThreadWeaver::DependentJob::completeJob();
 }
 
 
@@ -144,10 +167,29 @@ ScanController::initIncremental()
 {
     DEBUG_BLOCK
 
-    const QStringList values = CollectionDB::instance()->query( "SELECT dir, changedate FROM directories;" );
+    connect( CollectionDB::instance(),
+             SIGNAL( fileMoved( const QString &, const QString & ) ),
+             SLOT( slotFileMoved( const QString &, const QString & ) ) );
+    connect( CollectionDB::instance(),
+             SIGNAL( fileMoved( const QString &, const QString &, const QString & ) ),
+             SLOT( slotFileMoved( const QString &, const QString & ) ) );
+
+    IdList list = MountPointManager::instance()->getMountedDeviceIds();
+    QString deviceIds;
+    foreachType( IdList, list )
+    {
+        if ( !deviceIds.isEmpty() ) deviceIds += ',';
+        deviceIds += QString::number(*it);
+    }
+
+    const QStringList values = CollectionDB::instance()->query(
+            QString( "SELECT deviceid, dir, changedate FROM directories WHERE deviceid IN (%1);" )
+            .arg( deviceIds ) );
+
     foreach( values )
     {
-        const QString folder = *it;
+        int id = (*it).toInt();
+        const QString folder = MountPointManager::instance()->getAbsolutePath( id, (*++it) );
         const QString mtime  = *++it;
 
         const QFileInfo info( folder );
@@ -173,7 +215,7 @@ ScanController::initIncremental()
     {
         debug() << "Collection was modified." << endl;
         m_hasChanged = true;
-        amaroK::StatusBar::instance()->shortMessage( i18n( "Updating Collection..." ) );
+        Amarok::StatusBar::instance()->shortMessage( i18n( "Updating Collection..." ) );
 
         // Start scanner process
         if( AmarokConfig::scanRecursively() ) *m_scanner << "-r";
@@ -195,6 +237,12 @@ ScanController::doJob()
         return true;
 
     CollectionDB::instance()->createTables( true );
+    m_tablesCreated = true;
+
+    //For a full rescan, we might not have cleared tags table (for devices not plugged
+    //in), so preserve the necessary other tables (eg artist)
+    CollectionDB::instance()->prepareTempTables();
+
     CollectionDB::instance()->invalidateArtistAlbumCache();
     setProgressTotalSteps( 100 );
 
@@ -231,7 +279,9 @@ main_loop:
             if ( m_incremental ) {
                 m_foldersToRemove += m_folders;
                 foreach( m_foldersToRemove ) {
-                    CollectionDB::instance()->removeSongsInDir( *it );
+                    m_fileMapsMutex.lock();
+                    CollectionDB::instance()->removeSongsInDir( *it, &m_filesDeleted );
+                    m_fileMapsMutex.unlock();
                     CollectionDB::instance()->removeDirFromCollection( *it );
                 }
                 CollectionDB::instance()->removeOrphanedEmbeddedImages();
@@ -240,6 +290,18 @@ main_loop:
                 CollectionDB::instance()->clearTables( false ); // empty permanent tables
 
             CollectionDB::instance()->copyTempTables(); // copy temp into permanent tables
+
+            //Clean up unused entries in the main tables (eg artist, composer)
+            CollectionDB::instance()->deleteAllRedundant( "artist" );
+            CollectionDB::instance()->deleteAllRedundant( "composer" );
+            CollectionDB::instance()->deleteAllRedundant( "year" );
+            CollectionDB::instance()->deleteAllRedundant( "genre" );
+            CollectionDB::instance()->deleteAllRedundant( "album" );
+
+            //Remove free space and fragmentation in the DB. Used to run on shutdown, but
+            //that took too long, sometimes causing Amarok to be killed.
+            CollectionDB::instance()->vacuum();
+
         }
         else {
             if( m_crashedFiles.size() < MAX_RESTARTS ) {
@@ -254,7 +316,10 @@ main_loop:
     }
 
     if( CollectionDB::instance()->isConnected() )
+    {
+        m_tablesCreated = false;
         CollectionDB::instance()->dropTables( true ); // drop temp tables
+    }
 
     return !isAborted();
 }
@@ -273,6 +338,59 @@ ScanController::slotReadReady()
     m_dataMutex.unlock();
 }
 
+bool
+ScanController::requestPause()
+{
+    DEBUG_BLOCK
+    debug() << "Attempting to pause the collection scanner..." << endl;
+    DCOPRef dcopRef( "amarokcollectionscanner", "scanner" );
+    m_lastCommandPaused = true;
+    return dcopRef.send( "pause" );
+}
+
+bool
+ScanController::requestUnpause()
+{
+    DEBUG_BLOCK
+    debug() << "Attempting to unpause the collection scanner..." << endl;
+    DCOPRef dcopRef( "amarokcollectionscanner", "scanner" );
+    m_lastCommandPaused = false;
+    return dcopRef.send( "unpause" );
+}
+
+void
+ScanController::requestAcknowledged()
+{
+    DEBUG_BLOCK
+    if( m_waitingBundle )
+        m_waitingBundle->scannerAcknowledged();
+    if( m_lastCommandPaused )
+        m_isPaused = true;
+    else
+        m_isPaused = false;
+}
+
+void
+ScanController::slotFileMoved( const QString &/*src*/, const QString &/*dest*/)
+{
+    //why is this needed?  QBob, take a look at this
+    /*
+    if( m_incremental ) // pedantry
+      {
+        m_fileMapsMutex.lock();
+        m_filesFound[ src ] = true;
+        m_fileMapsMutex.unlock();
+      }
+    */
+}
+
+void
+ScanController::notifyThisBundle( MetaBundle* bundle )
+{
+    DEBUG_BLOCK
+    m_waitingBundle = bundle;
+    debug() << "will notify " << m_waitingBundle << endl;
+}
 
 bool
 ScanController::startElement( const QString&, const QString& localName, const QString&, const QXmlAttributes& attrs )
@@ -311,6 +429,7 @@ ScanController::startElement( const QString&, const QString& localName, const QS
         bundle.setYear      ( attrs.value( "year" ).toInt() );
         bundle.setTrack     ( attrs.value( "track" ).toInt() );
         bundle.setDiscNumber( attrs.value( "discnumber" ).toInt() );
+        bundle.setBpm       ( attrs.value( "bpm" ).toFloat() );
         bundle.setFileType( attrs.value( "filetype" ).toInt() );
         bundle.setUniqueId( attrs.value( "uniqueid" ) );
         bundle.setCompilation( attrs.value( "compilation" ).toInt() );
@@ -328,6 +447,12 @@ ScanController::startElement( const QString&, const QString& localName, const QS
         }
 
         CollectionDB::instance()->addSong( &bundle, m_incremental );
+        if( !bundle.uniqueId().isEmpty() )
+        {
+            m_fileMapsMutex.lock();
+            m_filesAdded[bundle.uniqueId()] = bundle.url().path();
+            m_fileMapsMutex.unlock();
+        }
     }
 
     else if( localName == "folder" ) {
@@ -377,14 +502,16 @@ ScanController::customEvent( QCustomEvent* e )
     {
         debug() << "RestartEvent received." << endl;
 
-        QFile log( amaroK::saveLocation( QString::null ) + "collection_scan.log" );
+        QFile log( Amarok::saveLocation( QString::null ) + "collection_scan.log" );
         log.open( IO_ReadOnly );
         m_crashedFiles << log.readAll();
 
+        m_dataMutex.lock();
         m_xmlData = QString::null;
-
         delete m_source;
         m_source = new QXmlInputSource();
+        m_dataMutex.unlock();
+
         delete m_reader;
         m_reader = new QXmlSimpleReader();
 
@@ -392,7 +519,7 @@ ScanController::customEvent( QCustomEvent* e )
         m_reader->parse( m_source, true );
 
         delete m_scanner; // Reusing doesn't work, so we have to destroy and reinstantiate
-        m_scanner = new ScannerProcIO();
+        m_scanner = new Amarok::ProcIO();
         connect( m_scanner, SIGNAL( readReady( KProcIO* ) ), SLOT( slotReadReady() ) );
 
         *m_scanner << "amarokcollectionscanner";
