@@ -30,6 +30,29 @@
 #include <qvbox.h>
 #include <qvgroupbox.h>
 
+enum Fields
+{
+    FArtist = 0,
+    FComposer,
+    FAlbum,
+    FGenre,
+    FTitle,
+    FLength,
+    FTrack,
+    FYear,
+    FComment,
+    FPlayCounter,
+    FScore,
+    FRating,
+    FFirstPlay,
+    FLastPlay,
+    FModfiedDate,
+    FFilePath,
+    FBPM,
+    FMountPoint,
+    FBitRate
+};
+
 
 QStringList m_fields;
 QStringList m_dbFields;
@@ -97,7 +120,7 @@ SmartPlaylistEditor::SmartPlaylistEditor( QWidget *parent, QDomElement xml, cons
         QDomElement orderby = orderbyList.item(0).toElement(); // we only allow one orderby node
 
         //random is always the last one.
-        int dbfield = orderby.attribute( "field" ) == "random" ? m_dbFields.count()-1 : m_dbFields.findIndex( orderby.attribute( "field" ) );
+        int dbfield = orderby.attribute( "field" ) == "random" ? m_dbFields.count() : m_dbFields.findIndex( orderby.attribute( "field" ) );
 
         m_orderCombo->setCurrentItem( dbfield );
         updateOrderTypes( dbfield );
@@ -129,21 +152,24 @@ void SmartPlaylistEditor::init(QString defaultName)
     makeVBoxMainWidget();
 
     m_fields.clear();
-    m_fields << i18n("Artist") << i18n("Album") << i18n("Genre") << i18n("Title") << i18n("Length") << i18n("Track #") << i18n("Year")
-             << i18n("Comment") << i18n("Play Counter") << i18n("Score") << i18n( "Rating" ) << i18n("First Play") << i18n("Last Play")
-             << i18n("Modified Date") << i18n("File Path");
+    m_fields << i18n("Artist") << i18n("Composer") << i18n("Album") << i18n("Genre") << i18n("Title") << i18n("Length")
+             << i18n("Track #") << i18n("Year") << i18n("Comment") << i18n("Play Counter")
+             << i18n("Score") << i18n( "Rating" ) << i18n("First Play")
+             << i18n("Last Play") << i18n("Modified Date") << i18n("File Path")
+             << i18n("BPM") << i18n("Mount Point") << i18n( "Bitrate" );
 
     m_dbFields.clear();
-    m_dbFields << "artist.name" << "album.name" << "genre.name" << "tags.title" << "tags.length"
+    m_dbFields << "artist.name" << "composer.name" << "album.name" << "genre.name" << "tags.title" << "tags.length"
                << "tags.track" << "year.name" << "tags.comment" << "statistics.playcounter"
                << "statistics.percentage" << "statistics.rating" << "statistics.createdate"
-               << "statistics.accessdate" << "tags.createdate" << "tags.url" << "tags.sampler";
+               << "statistics.accessdate" << "tags.createdate" << "tags.url"
+               << "tags.bpm" << "devices.lastmountpoint" << "tags.bitrate";
 
     m_expandableFields.clear();
-    m_expandableFields << i18n("Artist") << i18n("Album") << i18n("Genre") <<  i18n("Year");
+    m_expandableFields << i18n("Artist") << i18n("Composer") << i18n("Album") << i18n("Genre") <<  i18n("Year");
 
     m_expandableDbFields.clear();
-    m_expandableDbFields << "artist.name" << "album.name" << "genre.name" << "year.name";
+    m_expandableDbFields << "artist.name" << "composer.name" << "album.name" << "genre.name" << "year.name";
 
     QHBox *hbox = new QHBox( mainWidget() );
     hbox->setSpacing( 5 );
@@ -347,7 +373,10 @@ QDomElement SmartPlaylistEditor::result() {
 
         smartplaylist.appendChild( orderby );
     }
+    
     QDomElement Sql = doc.createElement("sqlquery");
+    Sql.appendChild( doc.createComment( "this element is deprecated, "
+                                        "and it is ignored" ) );
     buildQuery();
     Sql.appendChild( doc.createTextNode( m_query ) );
     smartplaylist.appendChild( Sql );
@@ -355,6 +384,9 @@ QDomElement SmartPlaylistEditor::result() {
     if( m_expandCheck->isChecked() ) {
         QDomElement expandBy = doc.createElement("expandby");
         expandBy.setAttribute( "field", m_expandableFields[ m_expandCombo->currentItem() ] );
+        expandBy.appendChild(
+            doc.createComment( "the SQL query in this element is deprecated, "
+                               "and it is ignored" ) );
         QDomText t = doc.createTextNode( m_expandQuery );
         expandBy.appendChild( t );
         smartplaylist.appendChild( expandBy );
@@ -366,9 +398,16 @@ QDomElement SmartPlaylistEditor::result() {
 void SmartPlaylistEditor::buildQuery()
 {
     DEBUG_BLOCK
+    //FIXME max: make sure sql queries are correct
 
+    // Note: the query built here is deprecated and kept only for forward compatibility
+    // with older amarok. Now the query is built at runtime in playlistbrowseritem.cpp
+    // This query no longer matches the field selection from collectiondb.cpp, but
+    // it does match the older versions, so an old Amarok will be able to read a
+    // smart playlist built by the newer version.
     QString joins = "tags LEFT JOIN year ON year.id=tags.year LEFT JOIN genre ON genre.id=tags.genre"
-                    " LEFT JOIN artist ON artist.id=tags.artist LEFT JOIN album ON album.id=tags.album";
+                    " LEFT JOIN artist ON artist.id=tags.artist LEFT JOIN album ON album.id=tags.album"
+                    " LEFT JOIN composer ON composer.id=tags.composer";
     QString whereStr;
     QString criteriaListStr;
     QString orderStr;
@@ -386,12 +425,14 @@ void SmartPlaylistEditor::buildQuery()
 
                 QString str = criteria->getSearchCriteria();
                 if( str.contains( "statistics." ) && !joins.contains( "statistics" ) )
-                    joins += " LEFT JOIN statistics ON statistics.url=tags.url";
+                    joins += " LEFT JOIN statistics ON statistics.url=tags.url AND statistics.deviceid=tags.deviceid";
+                if( str.contains( "devices." ) && !joins.contains( "devices" ) )
+                    joins += " LEFT JOIN devices ON tags.deviceid=devices.id";
 
                 if( i ) //multiple conditions
                     str.prepend( " OR (");
 
-                criteriaListStr += str+")";
+                criteriaListStr += str+')';
             }
 
             criteriaListStr += " )"; // we want our ORs all in one bracket. :-)
@@ -408,12 +449,14 @@ void SmartPlaylistEditor::buildQuery()
 
                 QString str = criteria2->getSearchCriteria();
                 if( str.contains( "statistics." ) && !joins.contains( "statistics" ) )
-                    joins += " LEFT JOIN statistics ON statistics.url=tags.url";
+                    joins += " LEFT JOIN statistics ON statistics.url=tags.url AND statistics.deviceid=tags.deviceid";
+                if( str.contains( "devices." ) && !joins.contains( "devices" ) )
+                    joins += " LEFT JOIN devices ON tags.deviceid=devices.id";
 
                 if( i ) //multiple conditions
                     str.prepend( " AND (");
 
-                criteriaListStr += str+")";
+                criteriaListStr += str+')';
             }
             criteriaListStr += " )";
         }
@@ -421,12 +464,15 @@ void SmartPlaylistEditor::buildQuery()
         whereStr = " WHERE " + criteriaListStr;
     }
 
+    //only select from mounted devices
+    whereStr = whereStr + " (*MountedDeviceSelection*) ";
+
     //order by expression
     if( m_orderCheck->isChecked() ) {
         if( m_orderCombo->currentItem() != m_orderCombo->count()-1 ) {
             QString field = m_dbFields[ m_orderCombo->currentItem() ];
             if( field.contains( "statistics." ) && !joins.contains( "statistics" ) )
-                joins += " LEFT JOIN statistics ON statistics.url=tags.url";
+                joins += " LEFT JOIN statistics ON statistics.url=tags.url AND statistics.deviceid=tags.deviceid";
 
             QString orderType = m_orderTypeCombo->currentItem() == 1 ? " DESC" : " ASC";
             orderStr = " ORDER BY " +  field + orderType;
@@ -439,7 +485,7 @@ void SmartPlaylistEditor::buildQuery()
             This is the score weighted random order.
             The RAND() function returns random values equally distributed between 0.0 (inclusive) and 1.0 (exclusive).
             The obvious way to get this order is to put every track <score> times into a list, sort the list by RAND()
-            (i.e. shuffle it) and discard every occurence of every track but the very first of each.
+            (i.e. shuffle it) and discard every occurrence of every track but the very first of each.
             By putting every track into the list only once but applying a transfer function
             T_s(x) := 1-(1-x)^(1/s) where s is the score, to RAND() before sorting the list, exactly the same
             distribution of tracks can be achieved (for a proof write to Stefan Siegel <kde@sdas.de>)
@@ -458,25 +504,22 @@ void SmartPlaylistEditor::buildQuery()
         limitStr = " LIMIT " + QString::number( m_limitSpin->value() )+" OFFSET 0 ";
 
 
-    // take care to adapt SmartPlaylist::NumReturnValues accordingly
-    // album / artist / genre / title / year / comment / track / bitrate / discnumber / length / samplerate / path / compilation / filetype / composer
-    m_query = "SELECT " + QueryBuilder::dragSQLFields() +
-                    " FROM " + joins + whereStr + orderStr + limitStr + ";";
+    // album / artist / composer / genre / title / year / comment / track / bitrate / discnumber / length / samplerate / path / compilation / filetype / bpm
+    m_query = "SELECT (*ListOfFields*) FROM "
+              + joins + whereStr + orderStr + limitStr + ';';
 
     if( m_expandCheck->isChecked() ) { //We use "(*ExpandString*)" as a marker, if a artist/track/album has this bizarre name, it won't work.
         QString field = m_expandableDbFields[ m_expandCombo->currentItem() ];
         QString table = field.left( field.find('.') );
         if( !joins.contains( table ) ) {
-            joins += " LEFT JOIN statistics ON statistics.url=tags.url";
+            joins += " LEFT JOIN statistics ON statistics.url=tags.url AND statistics.deviceid=tags.deviceid";
         }
         if ( !criteriaListStr.isEmpty() )
             whereStr = QString(" WHERE (%1) AND %2 = '(*ExpandString*)'").arg(criteriaListStr).arg(field);
         else
             whereStr = QString(" WHERE %1 = '(*ExpandString*)'").arg(field);
-        m_expandQuery = "SELECT album.name, artist.name, genre.name, tags.title, year.name, "
-                            "tags.comment, tags.track, tags.bitrate, tags.discnumber, tags.length,"
-                            "tags.samplerate, tags.filesize, tags.url, tags.sampler"
-                            " FROM " + joins + whereStr + orderStr + limitStr + ";";
+        m_expandQuery = "SELECT (*ListOfFields*) FROM "
+                        + joins + whereStr + orderStr + limitStr + ';';
     }
 }
 
@@ -740,7 +783,16 @@ QString CriteriaEditor::getSearchCriteria()
         searchCriteria += value;
     }
     else if( criteria == i18n("starts with") )
+    {
+        if( field == "tags.url" )
+        {
+            if( value.startsWith( "/" ) )
+                value = '.' + value;
+            if( !value.startsWith( "./" ) )
+                value = "./" + value;
+        }
         searchCriteria += CollectionDB::likeCondition( value, false, true );
+    }
     else if( criteria == i18n("ends with") )
         searchCriteria += CollectionDB::likeCondition( value, true, false );
     else if( criteria == i18n("is greater than") || criteria == i18n("is after") )
@@ -796,15 +848,17 @@ void CriteriaEditor::slotFieldSelected( int field )
     m_currentValueType = valueType;
 
     //enable auto-completion for artist, album and genre
-    if( valueType == AutoCompletionString ) { //Artist, Album, Genre
+    if( valueType == AutoCompletionString ) { //Artist, Composer, Album, Genre
         QStringList items;
         m_comboBox->clear();
         m_comboBox->completionObject()->clear();
 
         int currentField = m_fieldCombo->currentItem();
-        if( currentField == 0 ) //artist
+        if( currentField == FArtist ) //artist
            items = CollectionDB::instance()->artistList();
-        else if( currentField == 1 ) //album
+        else if( currentField == FComposer ) //composer
+           items = CollectionDB::instance()->composerList();
+        else if( currentField == FAlbum ) //album
            items = CollectionDB::instance()->albumList();
         else  //genre
            items = CollectionDB::instance()->genreList();
@@ -850,7 +904,7 @@ void CriteriaEditor::loadEditWidgets()
             break;
         }
 
-        case AutoCompletionString:    //artist, album, genre
+        case AutoCompletionString:    //artist, composer, album, genre
         {
             m_comboBox = new KComboBox( true, m_editBox );
             m_lineEdit = static_cast<KLineEdit*>( m_comboBox->lineEdit() );
@@ -945,7 +999,7 @@ void CriteriaEditor::loadEditWidgets()
 
 void CriteriaEditor::loadCriteriaList( int valueType, QString condition )
 {
-    if( m_currentValueType == valueType && condition == QString::null )
+    if( m_currentValueType == valueType && condition.isNull() )
         return;
 
     QStringList items;
@@ -987,26 +1041,30 @@ int CriteriaEditor::getValueType( int index )
     int valueType;
 
     switch( index ) {
-        case 0:
-        case 1:
-        case 2:
+        case FArtist:
+        case FComposer:
+        case FAlbum:
+        case FGenre:
             valueType = AutoCompletionString;
             break;
-        case 3:
-        case 7:
-        case 14:
+        case FTitle:
+        case FComment:
+        case FFilePath:
+        case FMountPoint:
             valueType = String;
             break;
-        case 4:
-        case 5:
-        case 8:
-        case 9:
+        case FLength:
+        case FTrack:
+        case FScore:
+        case FPlayCounter:
+        case FBPM:
+        case FBitRate:
             valueType = Number;
             break;
-        case 10:
+        case FRating:
             valueType = Rating;
             break;
-        case 6:
+        case FYear:
             valueType = Year;
             break;
         default: valueType = Date;
