@@ -277,14 +277,14 @@ StatisticsList::renderView()
         firstPlay.setTime_t( a[0].toUInt() );
 
     m_newestItem = new StatisticsItem( i18n("Newest Items"), this, m_genreItem );
-    m_newestItem->setSubtext( i18n("Listening since %1").arg( amaroK::verboseTimeSince( firstPlay ) ) );
+    m_newestItem->setSubtext( i18n("Listening since %1").arg( Amarok::verboseTimeSince( firstPlay ) ) );
 
-    m_trackItem     ->setIcon( amaroK::icon("track") );
-    m_mostplayedItem->setIcon( amaroK::icon("mostplayed") );
-    m_artistItem    ->setIcon( amaroK::icon("artist") );
-    m_albumItem     ->setIcon( amaroK::icon("album") );
-    m_genreItem     ->setIcon( amaroK::icon("favourite_genres") );
-    m_newestItem    ->setIcon( amaroK::icon("clock") );
+    m_trackItem     ->setIcon( Amarok::icon("track") );
+    m_mostplayedItem->setIcon( Amarok::icon("mostplayed") );
+    m_artistItem    ->setIcon( Amarok::icon("artist") );
+    m_albumItem     ->setIcon( Amarok::icon("album") );
+    m_genreItem     ->setIcon( Amarok::icon("favourite_genres") );
+    m_newestItem    ->setIcon( Amarok::icon("clock") );
 }
 
 void
@@ -321,10 +321,6 @@ StatisticsList::expandInformation( StatisticsItem *item, bool refresh )
     StatisticsDetailedItem *m_last = 0;
     uint c = 1;
 
-    const int sortBy = ( AmarokConfig::useScores() || !AmarokConfig::useRatings() )
-                       ? QueryBuilder::valPercentage
-                       : QueryBuilder::valRating;
-
     if( item == m_trackItem )
     {
         if( !refresh ) {
@@ -340,9 +336,9 @@ StatisticsList::expandInformation( StatisticsItem *item, bool refresh )
         qb.addReturnValue( QueryBuilder::tabSong, QueryBuilder::valURL );
         qb.addReturnValue( QueryBuilder::tabStats, QueryBuilder::valScore );
         qb.addReturnValue( QueryBuilder::tabStats, QueryBuilder::valRating );
-        qb.excludeFilter( QueryBuilder::tabStats, sortBy, "1", QueryBuilder::modeLess );
+        qb.excludeFilter( QueryBuilder::tabStats, QueryBuilder::valForFavoriteSorting(), "1", QueryBuilder::modeLess );
         qb.setGoogleFilter( QueryBuilder::tabSong | QueryBuilder::tabArtist, m_filter );
-        qb.sortBy( QueryBuilder::tabStats, sortBy, true );
+        qb.sortBy( QueryBuilder::tabStats, QueryBuilder::valForFavoriteSorting(), true );
         qb.setLimit( 0, 50 );
         QStringList fave = qb.run();
 
@@ -407,11 +403,11 @@ StatisticsList::expandInformation( StatisticsItem *item, bool refresh )
         qb.addReturnValue( QueryBuilder::tabArtist, QueryBuilder::valName );
         qb.addReturnFunctionValue( QueryBuilder::funcAvg, QueryBuilder::tabStats, QueryBuilder::valPercentage );
         qb.addReturnFunctionValue( QueryBuilder::funcAvg, QueryBuilder::tabStats, QueryBuilder::valRating );
-        qb.sortByFunction( QueryBuilder::funcAvg, QueryBuilder::tabStats, sortBy, true );
+        qb.sortByFunction( QueryBuilder::funcAvg, QueryBuilder::tabStats, QueryBuilder::valForFavoriteSorting(), true );
         // only artists with more than 3 tracks
         qb.having( QueryBuilder::tabArtist, QueryBuilder::valID, QueryBuilder::funcCount, QueryBuilder::modeGreater, "3" );
         // only artists which have been played/rated
-        qb.having( QueryBuilder::tabStats, sortBy, QueryBuilder::funcAvg, QueryBuilder::modeGreater, "0" );
+        qb.having( QueryBuilder::tabStats, QueryBuilder::valForFavoriteSorting(), QueryBuilder::funcAvg, QueryBuilder::modeGreater, "0" );
         qb.setGoogleFilter( QueryBuilder::tabArtist, m_filter );
         qb.groupBy( QueryBuilder::tabArtist, QueryBuilder::valName);
         qb.setLimit( 0, 50 );
@@ -450,9 +446,9 @@ StatisticsList::expandInformation( StatisticsItem *item, bool refresh )
         qb.addReturnValue( QueryBuilder::tabSong, QueryBuilder::valIsCompilation );
         // only albums with more than 3 tracks
         qb.having( QueryBuilder::tabAlbum, QueryBuilder::valID, QueryBuilder::funcCount, QueryBuilder::modeGreater, "3" );
-        qb.having( QueryBuilder::tabStats, sortBy, QueryBuilder::funcAvg, QueryBuilder::modeGreater, "0" );
+        qb.having( QueryBuilder::tabStats, QueryBuilder::valForFavoriteSorting(), QueryBuilder::funcAvg, QueryBuilder::modeGreater, "0" );
         qb.setGoogleFilter( QueryBuilder::tabAlbum | QueryBuilder::tabArtist, m_filter );
-        qb.sortByFunction( QueryBuilder::funcAvg, QueryBuilder::tabStats, sortBy, true );
+        qb.sortByFunction( QueryBuilder::funcAvg, QueryBuilder::tabStats, QueryBuilder::valForFavoriteSorting(), true );
         qb.excludeMatch( QueryBuilder::tabAlbum, i18n( "Unknown" ) );
         qb.groupBy( QueryBuilder::tabAlbum, QueryBuilder::valID );
         qb.groupBy( QueryBuilder::tabAlbum, QueryBuilder::valName );
@@ -498,9 +494,9 @@ StatisticsList::expandInformation( StatisticsItem *item, bool refresh )
         // only genres with more than 3 tracks
         qb.having( QueryBuilder::tabGenre, QueryBuilder::valID, QueryBuilder::funcCount, QueryBuilder::modeGreater, "3" );
         // only genres which have been played/rated
-        qb.having( QueryBuilder::tabStats, sortBy, QueryBuilder::funcAvg, QueryBuilder::modeGreater, "0" );
+        qb.having( QueryBuilder::tabStats, QueryBuilder::valForFavoriteSorting(), QueryBuilder::funcAvg, QueryBuilder::modeGreater, "0" );
         qb.setGoogleFilter( QueryBuilder::tabGenre, m_filter );
-        qb.sortByFunction( QueryBuilder::funcAvg, QueryBuilder::tabStats, sortBy, true );
+        qb.sortByFunction( QueryBuilder::funcAvg, QueryBuilder::tabStats, QueryBuilder::valForFavoriteSorting(), true );
         qb.groupBy( QueryBuilder::tabGenre, QueryBuilder::valName);
         qb.setLimit( 0, 50 );
         QStringList fave = qb.run();
@@ -553,7 +549,7 @@ StatisticsList::expandInformation( StatisticsItem *item, bool refresh )
                     newest[i+1].isEmpty() ? i18n( "Unknown" ) : newest[i+1] );
             QDateTime added = QDateTime();
             added.setTime_t( newest[i+4].toUInt() );
-            QString subtext = i18n("Added: %1").arg( amaroK::verboseTimeSince( added ) );
+            QString subtext = i18n("Added: %1").arg( Amarok::verboseTimeSince( added ) );
             m_last = new StatisticsDetailedItem( name, subtext, item, m_last );
             m_last->setItemType( StatisticsDetailedItem::HISTORY );
             QString url = QString("%1 @@@ %2").arg( newest[i+2] ).arg( newest[i+3] );
@@ -648,12 +644,12 @@ StatisticsList::showContextMenu( QListViewItem *item, const QPoint &p, int )  //
     KPopupMenu menu( this );
     enum Actions { APPEND, QUEUE, INFO };
 
-    menu.insertItem( SmallIconSet( amaroK::icon( "add_playlist" ) ), i18n( "&Append to Playlist" ), APPEND );
-    menu.insertItem( SmallIconSet( amaroK::icon( "fastforward" ) ), i18n( "&Queue Track" ), QUEUE );
+    menu.insertItem( SmallIconSet( Amarok::icon( "add_playlist" ) ), i18n( "&Append to Playlist" ), APPEND );
+    menu.insertItem( SmallIconSet( Amarok::icon( "queue_track" ) ), i18n( "&Queue Track" ), QUEUE );
 
     menu.insertSeparator();
 
-    menu.insertItem( SmallIconSet( amaroK::icon( "info" ) ), i18n( "Edit Track &Information..." ), INFO );
+    menu.insertItem( SmallIconSet( Amarok::icon( "info" ) ), i18n( "Edit Track &Information..." ), INFO );
 
     switch( menu.exec( p ) )
     {
@@ -968,7 +964,7 @@ StatisticsDetailedItem::getSQL()
     QueryBuilder qb;
     QString query = QString::null;
     QString artist, album, track;   // track is unused here
-    amaroK::albumArtistTrackFromUrl( url(), artist, album, track );
+    Amarok::albumArtistTrackFromUrl( url(), artist, album, track );
 
     if( itemType() == StatisticsDetailedItem::ALBUM || itemType() == StatisticsDetailedItem::HISTORY )
     {
@@ -1010,7 +1006,7 @@ StatisticsDetailedItem::getURLs()
     QueryBuilder qb;
     QString query = QString::null;
     QString artist, album, track;   // track is unused here
-    amaroK::albumArtistTrackFromUrl( m_url, artist, album, track );
+    Amarok::albumArtistTrackFromUrl( m_url, artist, album, track );
 
     qb.addReturnValue( QueryBuilder::tabSong, QueryBuilder::valURL );
 
